@@ -1,13 +1,16 @@
 import time
 from datetime import datetime
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
+from moto.athena.exceptions import InvalidArgumentException, QueryStillRunning
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
 from moto.moto_api._internal import mock_random
+from moto.moto_api._internal.managed_state_model import ManagedState
 from moto.s3.models import s3_backends
 from moto.s3.utils import bucket_and_name_from_url
 from moto.utilities.paginator import paginate
+from moto.utilities.tagging_service import TaggingService
 from moto.utilities.utils import get_partition
 
 
@@ -20,20 +23,20 @@ class TaggableResourceMixin:
         account_id: str,
         region_name: str,
         resource_name: str,
-        tags: List[Dict[str, str]],
+        tags: list[dict[str, str]],
     ):
         self.region = region_name
         self.resource_name = resource_name
         self.tags = tags or []
         self.arn = f"arn:{get_partition(region_name)}:athena:{region_name}:{account_id}:{resource_name}"
 
-    def create_tags(self, tags: List[Dict[str, str]]) -> List[Dict[str, str]]:
+    def create_tags(self, tags: list[dict[str, str]]) -> list[dict[str, str]]:
         new_keys = [tag_set["Key"] for tag_set in tags]
         self.tags = [tag_set for tag_set in self.tags if tag_set["Key"] not in new_keys]
         self.tags.extend(tags)
         return self.tags
 
-    def delete_tags(self, tag_keys: List[str]) -> List[Dict[str, str]]:
+    def delete_tags(self, tag_keys: list[str]) -> list[dict[str, str]]:
         self.tags = [tag_set for tag_set in self.tags if tag_set["Key"] not in tag_keys]
         return self.tags
 
@@ -46,9 +49,9 @@ class WorkGroup(TaggableResourceMixin, BaseModel):
         self,
         athena_backend: "AthenaBackend",
         name: str,
-        configuration: Dict[str, Any],
+        configuration: dict[str, Any],
         description: str,
-        tags: List[Dict[str, str]],
+        tags: list[dict[str, str]],
     ):
         self.region_name = athena_backend.region_name
         super().__init__(
@@ -85,7 +88,7 @@ class DataCatalog(TaggableResourceMixin, BaseModel):
         catalog_type: str,
         description: str,
         parameters: str,
-        tags: List[Dict[str, str]],
+        tags: list[dict[str, str]],
     ):
         self.region_name = athena_backend.region_name
         super().__init__(
@@ -101,15 +104,20 @@ class DataCatalog(TaggableResourceMixin, BaseModel):
         self.parameters = parameters
 
 
-class Execution(BaseModel):
+class Execution(ManagedState):
     def __init__(
         self,
         query: str,
         context: str,
-        config: Dict[str, Any],
+        config: dict[str, Any],
         workgroup: Optional[WorkGroup],
-        execution_parameters: Optional[List[str]],
+        execution_parameters: Optional[list[str]],
     ):
+        ManagedState.__init__(
+            self,
+            model_name="athena::execution",
+            transitions=[("QUEUED", "RUNNING"), ("RUNNING", "SUCCEEDED")],
+        )
         self.id = str(mock_random.uuid4())
         self.query = query
         self.context = context
@@ -117,7 +125,7 @@ class Execution(BaseModel):
         self.workgroup = workgroup
         self.execution_parameters = execution_parameters
         self.start_time = time.time()
-        self.status = "SUCCEEDED"
+        self.end_time = time.time()
 
         if self.config is not None and "OutputLocation" in self.config:
             if not self.config["OutputLocation"].endswith("/"):
@@ -126,11 +134,11 @@ class Execution(BaseModel):
 
 
 class QueryResults(BaseModel):
-    def __init__(self, rows: List[Dict[str, Any]], column_info: List[Dict[str, str]]):
+    def __init__(self, rows: list[dict[str, Any]], column_info: list[dict[str, str]]):
         self.rows = rows
         self.column_info = column_info
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
             "ResultSet": {
                 "Rows": self.rows,
@@ -139,6 +147,28 @@ class QueryResults(BaseModel):
         }
 
 
+class CapacityReservation(TaggableResourceMixin, BaseModel):
+    def __init__(
+        self,
+        athena_backend: "AthenaBackend",
+        name: str,
+        target_dpus: int,
+        tags: list[dict[str, str]],
+    ):
+        self.region_name = athena_backend.region_name
+        super().__init__(
+            athena_backend.account_id,
+            self.region_name,
+            f"capacity-reservation/{name}",
+            tags,
+        )
+        self.athena_backend = athena_backend
+        self.name = name
+        self.target_dpus = target_dpus
+        self.create_tags(tags)
+        self.tags = tags
+
+
 class NamedQuery(BaseModel):
     def __init__(
         self,
@@ -183,13 +213,15 @@ class AthenaBackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.work_groups: Dict[str, WorkGroup] = {}
-        self.executions: Dict[str, Execution] = {}
-        self.named_queries: Dict[str, NamedQuery] = {}
-        self.data_catalogs: Dict[str, DataCatalog] = {}
-        self.query_results: Dict[str, QueryResults] = {}
-        self.query_results_queue: List[QueryResults] = []
-        self.prepared_statements: Dict[str, PreparedStatement] = {}
+        self.work_groups: dict[str, WorkGroup] = {}
+        self.executions: dict[str, Execution] = {}
+        self.named_queries: dict[str, NamedQuery] = {}
+        self.capacity_reservations: dict[str, CapacityReservation] = {}
+        self.data_catalogs: dict[str, DataCatalog] = {}
+        self.query_results: dict[str, QueryResults] = {}
+        self.query_results_queue: list[QueryResults] = []
+        self.prepared_statements: dict[str, PreparedStatement] = {}
+        self.tagger = TaggingService()
 
         # Initialise with the primary workgroup
         self.create_work_group(
@@ -205,17 +237,18 @@ class AthenaBackend(BaseBackend):
     def create_work_group(
         self,
         name: str,
-        configuration: Dict[str, Any],
+        configuration: dict[str, Any],
         description: str,
-        tags: List[Dict[str, str]],
+        tags: list[dict[str, str]],
     ) -> Optional[WorkGroup]:
         if name in self.work_groups:
             return None
         work_group = WorkGroup(self, name, configuration, description, tags)
         self.work_groups[name] = work_group
+        self.tagger.tag_resource(work_group.arn, tags)
         return work_group
 
-    def list_work_groups(self) -> List[Dict[str, Any]]:
+    def list_work_groups(self) -> list[dict[str, Any]]:
         return [
             {
                 "Name": wg.name,
@@ -226,7 +259,7 @@ class AthenaBackend(BaseBackend):
             for wg in self.work_groups.values()
         ]
 
-    def get_work_group(self, name: str) -> Optional[Dict[str, Any]]:
+    def get_work_group(self, name: str) -> Optional[dict[str, Any]]:
         if name not in self.work_groups:
             return None
         wg = self.work_groups[name]
@@ -245,9 +278,9 @@ class AthenaBackend(BaseBackend):
         self,
         query: str,
         context: str,
-        config: Dict[str, Any],
+        config: dict[str, Any],
         workgroup: str,
-        execution_parameters: Optional[List[str]],
+        execution_parameters: Optional[list[str]],
     ) -> str:
         execution = Execution(
             query=query,
@@ -269,9 +302,14 @@ class AthenaBackend(BaseBackend):
             self._store_query_result_in_s3(exec_id)
 
     def get_query_execution(self, exec_id: str) -> Execution:
-        return self.executions[exec_id]
+        execution = self.executions[exec_id]
+        execution.advance()
+        return execution
 
-    def list_query_executions(self, workgroup: Optional[str]) -> Dict[str, Execution]:
+    def list_query_executions(self, workgroup: Optional[str]) -> dict[str, Execution]:
+        # Note: We do not advance the execution status here, only in `get_query_execution`
+        # This method simply returns the QueryExecutionIds to the user
+        # They will always have to call `get_query_execution` to get the status
         if workgroup is not None:
             return {
                 exec_id: execution
@@ -328,6 +366,9 @@ class AthenaBackend(BaseBackend):
         Query results will also be stored in the S3 output location (in CSV format).
 
         """
+        if (exctn := self.executions.get(exec_id)) and exctn.status != "SUCCEEDED":
+            raise QueryStillRunning(current_status=exctn.status)
+
         self._store_predefined_query_results(exec_id)
 
         results = (
@@ -366,6 +407,32 @@ class AthenaBackend(BaseBackend):
         execution = self.executions[exec_id]
         execution.status = "CANCELLED"
 
+    def create_capacity_reservation(
+        self,
+        name: str,
+        target_dpus: int,
+        tags: list[dict[str, str]],
+    ) -> None:
+        cr = CapacityReservation(self, name, target_dpus, tags)
+        self.capacity_reservations[cr.name] = cr
+        self.tagger.tag_resource(cr.arn, tags)
+        return None
+
+    def get_capacity_reservation(self, name: str) -> Optional[CapacityReservation]:
+        return self.capacity_reservations.get(name)
+
+    def list_capacity_reservations(self) -> list[dict[str, Any]]:
+        return [
+            {"Name": cr.name, "TargetDpus": cr.target_dpus, "CreationTime": time.time()}
+            for cr in self.capacity_reservations.values()
+        ]
+
+    def update_capacity_reservation(self, name: str, target_dpus: int) -> None:
+        if name not in self.capacity_reservations:
+            raise InvalidArgumentException("Capacity Reservation does not exist")
+
+        self.capacity_reservations[name].target_dpus = target_dpus
+
     def create_named_query(
         self,
         name: str,
@@ -387,13 +454,13 @@ class AthenaBackend(BaseBackend):
     def get_named_query(self, query_id: str) -> Optional[NamedQuery]:
         return self.named_queries[query_id] if query_id in self.named_queries else None
 
-    def list_data_catalogs(self) -> List[Dict[str, str]]:
+    def list_data_catalogs(self) -> list[dict[str, str]]:
         return [
             {"CatalogName": dc.name, "Type": dc.type}
             for dc in self.data_catalogs.values()
         ]
 
-    def get_data_catalog(self, name: str) -> Optional[Dict[str, str]]:
+    def get_data_catalog(self, name: str) -> Optional[dict[str, str]]:
         if name not in self.data_catalogs:
             return None
         dc = self.data_catalogs[name]
@@ -410,7 +477,7 @@ class AthenaBackend(BaseBackend):
         catalog_type: str,
         description: str,
         parameters: str,
-        tags: List[Dict[str, str]],
+        tags: list[dict[str, str]],
     ) -> Optional[DataCatalog]:
         if name in self.data_catalogs:
             return None
@@ -418,10 +485,11 @@ class AthenaBackend(BaseBackend):
             self, name, catalog_type, description, parameters, tags
         )
         self.data_catalogs[name] = data_catalog
+        self.tagger.tag_resource(data_catalog.arn, tags)
         return data_catalog
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_named_queries(self, work_group: str) -> List[str]:
+    def list_named_queries(self, work_group: str) -> list[str]:
         named_query_ids = [
             q.id for q in self.named_queries.values() if q.workgroup.name == work_group
         ]
@@ -452,5 +520,17 @@ class AthenaBackend(BaseBackend):
                 return ps
         return None
 
+    def get_query_runtime_statistics(
+        self, query_execution_id: str
+    ) -> Optional[Execution]:
+        if query_execution_id in self.executions:
+            return self.executions[query_execution_id]
+        return None
+
+    def list_tags_for_resource(self, resource_arn: str) -> Optional[dict[str, Any]]:
+        if self.tagger.has_tags(resource_arn):
+            return self.tagger.list_tags_for_resource(resource_arn)
+        return None
+
 
 athena_backends = BackendDict(AthenaBackend, "athena")
