@@ -1,7 +1,5 @@
 """Exceptions raised by the comprehend service."""
 
-from typing import List
-
 from moto.core.exceptions import JsonRESTError
 
 
@@ -14,7 +12,7 @@ class ResourceNotFound(JsonRESTError):
 
 
 class DetectPIIValidationException(JsonRESTError):
-    def __init__(self, language: str, all_languages: List[str]) -> None:
+    def __init__(self, language: str, all_languages: list[str]) -> None:
         all_languages_str = str(all_languages).replace("'", "")
         super().__init__(
             "ValidationException",
@@ -30,3 +28,8 @@ class TextSizeLimitExceededException(JsonRESTError):
             "Input text size exceeds limit. Max length of request text allowed is 100000 bytes while in "
             f"this request the text size is {size} bytes",
         )
+
+
+class InvalidRequestException(JsonRESTError):
+    def __init__(self, message: str) -> None:
+        super().__init__("InvalidRequestException", message)
