@@ -1,6 +1,10 @@
 from .models import DEFAULT_ACCOUNT_ID  # noqa
 from .models import patch_client, patch_resource  # noqa
-from .responses import ActionAuthenticatorMixin
+from .authorization import ActionAuthenticatorMixin
+from .authorization import (
+    enable_iam_authentication as enable_iam_authentication,
+    disable_iam_authentication as disable_iam_authentication,
+)
 
 set_initial_no_auth_action_count = (
     ActionAuthenticatorMixin.set_initial_no_auth_action_count
