@@ -1,14 +1,21 @@
+from __future__ import annotations
+
 import datetime
 import inspect
 import re
+from functools import cache
 from gzip import compress, decompress
-from typing import Any, Callable, Dict, List, Optional, Tuple
+from typing import Any, Callable, Optional
 from urllib.parse import ParseResult, urlparse
 
 from botocore.exceptions import ClientError
 
+from moto.core.model import ServiceModel
+
 from ..settings import get_s3_custom_endpoints
 from .common_types import TYPE_RESPONSE
+from .constants import MISSING
+from .loaders import create_loader
 from .versions import PYTHON_311
 
 
@@ -64,7 +71,7 @@ def camelcase_to_pascal(argument: str) -> str:
     return argument[0].upper() + argument[1:]
 
 
-def method_names_from_class(clazz: object) -> List[str]:
+def method_names_from_class(clazz: object) -> list[str]:
     predicate = inspect.isfunction
     return [x[0] for x in inspect.getmembers(clazz, predicate=predicate)]
 
@@ -88,7 +95,7 @@ def convert_regex_to_flask_path(url_path: str) -> str:
     return url_path
 
 
-class convert_to_flask_response(object):
+class convert_to_flask_response:
     def __init__(self, callback: Callable[..., Any]):
         self.callback = callback
 
@@ -124,7 +131,7 @@ class convert_to_flask_response(object):
         return response
 
 
-class convert_flask_to_responses_response(object):
+class convert_flask_to_responses_response:
     def __init__(self, callback: Callable[..., Any]):
         self.callback = callback
 
@@ -170,6 +177,14 @@ def iso_8601_datetime_without_milliseconds_s3(
     return value.strftime("%Y-%m-%dT%H:%M:%S.000Z") if value else None
 
 
+RFC3339_DATETIME_PATTERN = re.compile(
+    r"^\d{4}-\d{2}-\d{2}"  # YYYY-MM-DD
+    r"[Tt]"  # 'T' or 't' separator
+    r"\d{2}:\d{2}:\d{2}"  # HH:MM:SS
+    r"(?:\.\d+)?"  # Optional fractional seconds (e.g., .123)
+    r"(?:[Zz]|(?:\+|-)\d{2}:\d{2})$"  # 'Z' or 'z' for UTC, or +/-HH:MM offset
+)
+
 RFC1123 = "%a, %d %b %Y %H:%M:%S GMT"
 EN_WEEKDAYS = ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"]
 EN_MONTHS = [
@@ -261,28 +276,9 @@ def path_url(url: str) -> str:
     return path
 
 
-def tags_from_query_string(
-    querystring_dict: Dict[str, Any],
-    prefix: str = "Tag",
-    key_suffix: str = "Key",
-    value_suffix: str = "Value",
-) -> Dict[str, str]:
-    response_values = {}
-    for key in querystring_dict.keys():
-        if key.startswith(prefix) and key.endswith(key_suffix):
-            tag_index = key.replace(prefix + ".", "").replace("." + key_suffix, "")
-            tag_key = querystring_dict[f"{prefix}.{tag_index}.{key_suffix}"][0]
-            tag_value_key = f"{prefix}.{tag_index}.{value_suffix}"
-            if tag_value_key in querystring_dict:
-                response_values[tag_key] = querystring_dict[tag_value_key][0]
-            else:
-                response_values[tag_key] = None
-    return response_values
-
-
 def tags_from_cloudformation_tags_list(
-    tags_list: List[Dict[str, str]],
-) -> Dict[str, str]:
+    tags_list: list[dict[str, str]],
+) -> dict[str, str]:
     """Return tags in dict form from cloudformation resource tags form (list of dicts)"""
     tags = {}
     for entry in tags_list:
@@ -321,33 +317,31 @@ def remap_nested_keys(root: Any, key_transform: Callable[[str], str]) -> Any:
 
 
 def merge_dicts(
-    dict1: Dict[str, Any], dict2: Dict[str, Any], remove_nulls: bool = False
+    dict1: dict[str, Any], dict2: dict[str, Any], remove_nulls: bool = False
 ) -> None:
     """Given two arbitrarily nested dictionaries, merge the second dict into the first.
 
     :param dict dict1: the dictionary to be updated.
     :param dict dict2: a dictionary of keys/values to be merged into dict1.
 
-    :param bool remove_nulls: If true, updated values equal to None or an empty dictionary
+    :param bool remove_nulls: If true, updated values equal to None
         will be removed from dict1.
     """
     for key in dict2:
         if isinstance(dict2[key], dict):
-            if key in dict1 and key in dict2:
+            if key in dict1 and isinstance(dict1[key], dict):
                 merge_dicts(dict1[key], dict2[key], remove_nulls)
             else:
                 dict1[key] = dict2[key]
                 if isinstance(dict1[key], dict):
                     remove_null_from_dict(dict1)
-            if dict1[key] == {} and remove_nulls:
-                dict1.pop(key)
         else:
             dict1[key] = dict2[key]
             if dict1[key] is None and remove_nulls:
                 dict1.pop(key)
 
 
-def remove_null_from_dict(dct: Dict[str, Any]) -> None:
+def remove_null_from_dict(dct: dict[str, Any]) -> None:
     for key in list(dct.keys()):
         if dct[key] is None:
             dct.pop(key)
@@ -384,21 +378,6 @@ def extract_region_from_aws_authorization(string: str) -> Optional[str]:
     return region
 
 
-def params_sort_function(item: Tuple[str, Any]) -> Tuple[str, int, str]:
-    """
-    sort by <string-prefix>.member.<integer>.<string-postfix>:
-    in case there are more than 10 members, the default-string sort would lead to IndexError when parsing the content.
-
-    Note: currently considers only the first occurence of `member`, but there may be cases with nested members
-    """
-    key, _ = item
-
-    match = re.search(r"(.*?member)\.(\d+)(.*)", key)
-    if match:
-        return (match.group(1), int(match.group(2)), match.group(3))
-    return (key, 0, "")
-
-
 def gzip_decompress(body: bytes) -> bytes:
     return decompress(body)
 
@@ -416,7 +395,7 @@ ISO_REGION_DOMAINS = {
 ALT_DOMAIN_SUFFIXES = list(ISO_REGION_DOMAINS.values()) + ["amazonaws.com.cn"]
 
 
-def get_equivalent_url_in_aws_domain(url: str) -> Tuple[ParseResult, bool]:
+def get_equivalent_url_in_aws_domain(url: str) -> tuple[ParseResult, bool]:
     """Parses a URL and converts non-standard AWS endpoint hostnames (from ISO
     regions or custom S3 endpoints) to the equivalent standard AWS domain.
 
@@ -451,3 +430,40 @@ def get_equivalent_url_in_aws_domain(url: str) -> Tuple[ParseResult, bool]:
             fragment=parsed.fragment,
         )
         return (result, True)
+
+
+@cache
+def get_service_model(service_name: str) -> ServiceModel:
+    loader = create_loader()
+    model = loader.load_service_model(service_name, "service-2")
+    service_model = ServiceModel(model, service_name)
+    return service_model
+
+
+def get_value(obj: Any, key: int | str, default: Any = MISSING) -> Any:
+    """Helper for pulling a keyed value off various types of objects.
+
+    A key containing a dot (e.g. `parent.child`) will be treated as a
+    path to traverse to get to the desired value.
+    """
+    if not isinstance(key, int) and "." in key:
+        return _get_value_for_keys(obj, key.split("."), default)
+    return _get_value_for_key(obj, key, default)
+
+
+def _get_value_for_keys(obj: Any, keys: list[str], default: Any) -> Any:
+    if len(keys) == 1:
+        return _get_value_for_key(obj, keys[0], default)
+    return _get_value_for_keys(
+        _get_value_for_key(obj, keys[0], default), keys[1:], default
+    )
+
+
+def _get_value_for_key(obj: Any, key: int | str, default: Any) -> Any:
+    if not hasattr(obj, "__getitem__"):
+        return getattr(obj, str(key), default)
+
+    try:
+        return obj[key]
+    except (KeyError, IndexError, TypeError, AttributeError):
+        return default
