@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Optional, Union
 
 from moto.dynamodb.exceptions import KeyIsEmptyStringException, MockValidationException
 from moto.utilities.tokenizer import GenericTokenizer
@@ -13,17 +13,17 @@ class EXPRESSION_STAGES(Enum):
     EOF = "EOF"
 
 
-def get_key(schema: List[Dict[str, str]], key_type: str) -> Optional[str]:
+def get_key(schema: list[dict[str, str]], key_type: str) -> Optional[str]:
     keys = [key for key in schema if key["KeyType"] == key_type]
     return keys[0]["AttributeName"] if keys else None
 
 
 def parse_expression(
     key_condition_expression: str,
-    expression_attribute_values: Dict[str, Dict[str, str]],
-    expression_attribute_names: Dict[str, str],
-    schema: List[Dict[str, str]],
-) -> Tuple[Dict[str, Any], Optional[str], List[Dict[str, Any]]]:
+    expression_attribute_values: dict[str, dict[str, str]],
+    expression_attribute_names: dict[str, str],
+    schema: list[dict[str, str]],
+) -> tuple[dict[str, Any], Optional[str], list[dict[str, Any]], list[str]]:
     """
     Parse a KeyConditionExpression using the provided expression attribute names/values
 
@@ -36,8 +36,9 @@ def parse_expression(
     current_stage: Optional[EXPRESSION_STAGES] = None
     current_phrase = ""
     key_name = comparison = ""
-    key_values: List[Union[Dict[str, str], str]] = []
-    results: List[Tuple[str, str, Any]] = []
+    key_values: list[Union[dict[str, str], str]] = []
+    expression_attribute_names_used: list[str] = []
+    results: list[tuple[str, str, Any]] = []
     tokenizer = GenericTokenizer(key_condition_expression)
     for crnt_char in tokenizer:
         if crnt_char == " ":
@@ -50,9 +51,11 @@ def parse_expression(
                 else:
                     # start_date < :sk and primary = :pk
                     #            ^
-                    key_name = expression_attribute_names.get(
-                        current_phrase, current_phrase
-                    )
+                    if expression_attribute_names.get(current_phrase):
+                        key_name = expression_attribute_names[current_phrase]
+                        expression_attribute_names_used.append(current_phrase)
+                    else:
+                        key_name = current_phrase
                     current_phrase = ""
                     current_stage = EXPRESSION_STAGES.COMPARISON
                     tokenizer.skip_white_space()
@@ -103,9 +106,11 @@ def parse_expression(
                 EXPRESSION_STAGES.KEY_NAME,
                 EXPRESSION_STAGES.INITIAL_STAGE,
             ]:
-                key_name = expression_attribute_names.get(
-                    current_phrase, current_phrase
-                )
+                if expression_attribute_names.get(current_phrase):
+                    key_name = expression_attribute_names[current_phrase]
+                    expression_attribute_names_used.append(current_phrase)
+                else:
+                    key_name = current_phrase
             current_phrase = ""
             if crnt_char in ["<", ">"] and tokenizer.peek() == "=":
                 comparison = crnt_char + tokenizer.__next__()
@@ -118,9 +123,11 @@ def parse_expression(
             if current_stage == EXPRESSION_STAGES.KEY_NAME:
                 # hashkey = :id and begins_with(sortkey,     :sk)
                 #                                      ^ --> ^
-                key_name = expression_attribute_names.get(
-                    current_phrase, current_phrase
-                )
+                if expression_attribute_names.get(current_phrase):
+                    key_name = expression_attribute_names[current_phrase]
+                    expression_attribute_names_used.append(current_phrase)
+                else:
+                    key_name = current_phrase
                 current_phrase = ""
                 current_stage = EXPRESSION_STAGES.KEY_VALUE
                 tokenizer.skip_white_space()
@@ -192,13 +199,14 @@ def parse_expression(
         hash_value,
         range_comparison.upper() if range_comparison else None,
         range_values,
+        expression_attribute_names_used,
     )
 
 
 # Validate that the schema-keys are encountered in our query
 def validate_schema(
-    results: Any, schema: List[Dict[str, str]]
-) -> Tuple[Dict[str, Any], Optional[str], List[Dict[str, Any]]]:
+    results: Any, schema: list[dict[str, str]]
+) -> tuple[dict[str, Any], Optional[str], list[dict[str, Any]]]:
     index_hash_key = get_key(schema, "HASH")
     comparison, hash_value = next(
         (
@@ -234,4 +242,9 @@ def validate_schema(
         if {"S": ""} in range_values:
             raise KeyIsEmptyStringException(index_range_key)
 
+    provided_keys = [key for key, _, _ in results]
+    schema_keys = [x["AttributeName"] for x in schema]
+    if any(x not in schema_keys for x in provided_keys):
+        raise MockValidationException("Query key condition not supported")
+
     return hash_value, range_comparison, range_values
