@@ -1,28 +1,52 @@
-import json
-from typing import Any, Dict
+from __future__ import annotations
 
-from moto.core.responses import BaseResponse
+import json
+
+from moto.core.responses import ActionResult, BaseResponse, EmptyResult
 from moto.core.utils import camelcase_to_underscores
 
 from .models import EC2ContainerServiceBackend, ecs_backends
 
+DESCRIBE_CLUSTERS_TAGS = "DescribeClustersResponse.clusters.Cluster.tags"
+DESCRIBE_SERVICES_TAGS = "DescribeServicesResponse.services.Service.tags"
+DESCRIBE_TASKS_TAGS = "DescribeTasksResponse.tasks.Task.tags"
+DESCRIBE_TASK_SETS_TAGS = "DescribeTaskSetsResponse.taskSets.TaskSet.tags"
+
+
+# ContainerInstance.Attribute is a multi-field structure (name, value, targetType, targetId),
+# but is currently stored as a dictionary (key=name, value=value) on the Moto ECS backend.
+# For now, we use this transformer to convert the attributes dictionary into a data structure
+# that matches the AWS spec.
+# TODO: model ContainerInstance.Attribute properly on the backend and remove this transformer.
+def format_attributes(attributes: dict[str, str] | None) -> list[dict[str, str]] | None:
+    if attributes is None:
+        return None
+    formatted = [{"name": name, "value": value} for name, value in attributes.items()]
+    return formatted
+
 
 class EC2ContainerServiceResponse(BaseResponse):
+    RESPONSE_KEY_PATH_TO_TRANSFORMER = {
+        "DescribeContainerInstancesResponse.containerInstances.ContainerInstance.attributes": format_attributes,
+        "RegisterContainerInstanceResponse.containerInstance.attributes": format_attributes,
+    }
+
     def __init__(self) -> None:
         super().__init__(service_name="ecs")
+        self.automated_parameter_parsing = True
 
     @property
     def ecs_backend(self) -> EC2ContainerServiceBackend:
         return ecs_backends[self.current_account][self.region]
 
-    def create_capacity_provider(self) -> str:
+    def create_capacity_provider(self) -> ActionResult:
         name = self._get_param("name")
         asg_provider = self._get_param("autoScalingGroupProvider")
         tags = self._get_param("tags")
         provider = self.ecs_backend.create_capacity_provider(name, asg_provider, tags)
-        return json.dumps({"capacityProvider": provider.response_object})
+        return ActionResult({"capacityProvider": provider})
 
-    def create_cluster(self) -> str:
+    def create_cluster(self) -> ActionResult:
         cluster_name = self._get_param("clusterName")
         tags = self._get_param("tags")
         settings = self._get_param("settings")
@@ -43,13 +67,13 @@ class EC2ContainerServiceResponse(BaseResponse):
             default_capacity_provider_strategy,
             service_connect_defaults=service_connect_defaults,
         )
-        return json.dumps({"cluster": cluster.response_object})
+        return ActionResult({"cluster": cluster})
 
-    def list_clusters(self) -> str:
+    def list_clusters(self) -> ActionResult:
         cluster_arns = self.ecs_backend.list_clusters()
-        return json.dumps({"clusterArns": cluster_arns})
+        return ActionResult({"clusterArns": cluster_arns})
 
-    def update_cluster(self) -> str:
+    def update_cluster(self) -> ActionResult:
         cluster_name = self._get_param("cluster")
         settings = self._get_param("settings")
         configuration = self._get_param("configuration")
@@ -60,9 +84,9 @@ class EC2ContainerServiceResponse(BaseResponse):
             configuration=configuration,
             service_connect_defaults=service_connect_defaults,
         )
-        return json.dumps({"cluster": cluster.response_object})
+        return ActionResult({"cluster": cluster})
 
-    def put_cluster_capacity_providers(self) -> str:
+    def put_cluster_capacity_providers(self) -> ActionResult:
         cluster_name = self._get_param("cluster")
         capacity_providers = self._get_param("capacityProviders")
         default_capacity_provider_strategy = self._get_param(
@@ -71,46 +95,49 @@ class EC2ContainerServiceResponse(BaseResponse):
         cluster = self.ecs_backend.put_cluster_capacity_providers(
             cluster_name, capacity_providers, default_capacity_provider_strategy
         )
-        return json.dumps({"cluster": cluster.response_object})
+        return ActionResult({"cluster": cluster})
 
-    def delete_capacity_provider(self) -> str:
+    def delete_capacity_provider(self) -> ActionResult:
         name = self._get_param("capacityProvider")
         provider = self.ecs_backend.delete_capacity_provider(name)
-        return json.dumps({"capacityProvider": provider.response_object})
+        return ActionResult({"capacityProvider": provider})
 
-    def update_capacity_provider(self) -> str:
+    def update_capacity_provider(self) -> ActionResult:
         name = self._get_param("name")
         asg_provider = self._get_param("autoScalingGroupProvider")
         provider = self.ecs_backend.update_capacity_provider(name, asg_provider)
-        return json.dumps({"capacityProvider": provider.response_object})
+        return ActionResult({"capacityProvider": provider})
 
-    def describe_capacity_providers(self) -> str:
+    def describe_capacity_providers(self) -> ActionResult:
         names = self._get_param("capacityProviders")
         providers, failures = self.ecs_backend.describe_capacity_providers(names)
-        return json.dumps(
+        return ActionResult(
             {
-                "capacityProviders": [p.response_object for p in providers],
-                "failures": [p.response_object for p in failures],
+                "capacityProviders": providers,
+                "failures": failures,
             }
         )
 
-    def describe_clusters(self) -> str:
-        names = self._get_param("clusters")
-        include = self._get_param("include")
-        clusters, failures = self.ecs_backend.describe_clusters(names, include)
-        return json.dumps(
-            {
-                "clusters": clusters,
-                "failures": [cluster.response_object for cluster in failures],
-            }
-        )
+    def describe_clusters(self) -> ActionResult:
+        cluster_names = self._get_param("clusters", [])
+        clusters, failures = self.ecs_backend.describe_clusters(cluster_names)
+        include = self._get_param("include", [])
+        if "TAGS" in include:
+            self._include_in_response(DESCRIBE_CLUSTERS_TAGS)
+        else:
+            self._exclude_from_response(DESCRIBE_CLUSTERS_TAGS)
+        result = {
+            "clusters": clusters,
+            "failures": failures,
+        }
+        return ActionResult(result)
 
-    def delete_cluster(self) -> str:
+    def delete_cluster(self) -> ActionResult:
         cluster_str = self._get_param("cluster")
         cluster = self.ecs_backend.delete_cluster(cluster_str)
-        return json.dumps({"cluster": cluster.response_object})
+        return ActionResult({"cluster": cluster})
 
-    def register_task_definition(self) -> str:
+    def register_task_definition(self) -> ActionResult:
         family = self._get_param("family")
         container_definitions = self._get_param("containerDefinitions")
         volumes = self._get_param("volumes")
@@ -148,30 +175,32 @@ class EC2ContainerServiceResponse(BaseResponse):
             pid_mode=pid_mode,
             ephemeral_storage=ephemeral_storage,
         )
-        return json.dumps(task_definition.response_object)
+        return ActionResult({"taskDefinition": task_definition})
 
-    def list_task_definitions(self) -> str:
+    def list_task_definitions(self) -> ActionResult:
         family_prefix = self._get_param("familyPrefix")
-        task_definition_arns = self.ecs_backend.list_task_definitions(family_prefix)
-        return json.dumps({"taskDefinitionArns": task_definition_arns})
+        status = self._get_param("status", "ACTIVE")
+        task_definition_arns = self.ecs_backend.list_task_definitions(
+            family_prefix, status
+        )
+        return ActionResult({"taskDefinitionArns": task_definition_arns})
 
-    def describe_task_definition(self) -> str:
+    def describe_task_definition(self) -> ActionResult:
         task_definition_str = self._get_param("taskDefinition")
-        data = self.ecs_backend.describe_task_definition(task_definition_str)
-        resp: Dict[str, Any] = data.response_object
-        resp["failures"] = []
+        task_definition = self.ecs_backend.describe_task_definition(task_definition_str)
+        resp = {"taskDefinition": task_definition, "failures": []}
         if "TAGS" in self._get_param("include", []):
-            resp["tags"] = self.ecs_backend.list_tags_for_resource(data.arn)
-        return json.dumps(resp)
+            resp["tags"] = self.ecs_backend.list_tags_for_resource(task_definition.arn)
+        return ActionResult(resp)
 
-    def deregister_task_definition(self) -> str:
+    def deregister_task_definition(self) -> ActionResult:
         task_definition_str = self._get_param("taskDefinition")
         task_definition = self.ecs_backend.deregister_task_definition(
             task_definition_str
         )
-        return json.dumps(task_definition.response_object)
+        return ActionResult({"taskDefinition": task_definition})
 
-    def run_task(self) -> str:
+    def run_task(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         overrides = self._get_param("overrides")
         task_definition_str = self._get_param("taskDefinition")
@@ -180,6 +209,8 @@ class EC2ContainerServiceResponse(BaseResponse):
         tags = self._get_param("tags")
         launch_type = self._get_param("launchType")
         network_configuration = self._get_param("networkConfiguration")
+        group = self._get_param("group")
+        platform_version = self._get_param("platformVersion")
         tasks = self.ecs_backend.run_task(
             cluster_str,
             task_definition_str,
@@ -189,30 +220,34 @@ class EC2ContainerServiceResponse(BaseResponse):
             tags,
             launch_type,
             network_configuration,
+            group,
+            platform_version,
         )
-        return json.dumps(
-            {"tasks": [task.response_object() for task in tasks], "failures": []}
-        )
+        return ActionResult({"tasks": tasks, "failures": []})
 
-    def describe_tasks(self) -> str:
+    def describe_tasks(self) -> ActionResult:
         cluster = self._get_param("cluster", "default")
-        tasks = self._get_param("tasks")
-        include_tags = "TAGS" in self._get_param("include", [])
-        data = self.ecs_backend.describe_tasks(cluster, tasks)
-        return json.dumps(
-            {
-                "tasks": [task.response_object(include_tags) for task in data],
-                "failures": [],
-            }
-        )
+        task_ids = self._get_param("tasks", [])
+        tasks = self.ecs_backend.describe_tasks(cluster, task_ids)
+        include = self._get_param("include", [])
+        if "TAGS" in include:
+            self._include_in_response(DESCRIBE_TASKS_TAGS)
+        else:
+            self._exclude_from_response(DESCRIBE_TASKS_TAGS)
+        result = {
+            "tasks": tasks,
+            "failures": [],
+        }
+        return ActionResult(result)
 
-    def start_task(self) -> str:
+    def start_task(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         overrides = self._get_param("overrides")
         task_definition_str = self._get_param("taskDefinition")
         container_instances = self._get_param("containerInstances")
         started_by = self._get_param("startedBy")
         tags = self._get_param("tags")
+        group = self._get_param("group")
         tasks = self.ecs_backend.start_task(
             cluster_str,
             task_definition_str,
@@ -220,36 +255,35 @@ class EC2ContainerServiceResponse(BaseResponse):
             overrides,
             started_by,
             tags,
+            group,
         )
-        return json.dumps(
-            {"tasks": [task.response_object() for task in tasks], "failures": []}
-        )
+        return ActionResult({"tasks": tasks, "failures": []})
 
-    def list_tasks(self) -> str:
+    def list_tasks(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         container_instance = self._get_param("containerInstance")
         family = self._get_param("family")
         started_by = self._get_param("startedBy")
         service_name = self._get_param("serviceName")
-        desiredStatus = self._get_param("desiredStatus")
+        desired_status = self._get_param("desiredStatus")
         tasks = self.ecs_backend.list_tasks(
             cluster_str,
             container_instance,
             family,
             started_by,
             service_name,
-            desiredStatus,
+            desired_status,
         )
-        return json.dumps({"taskArns": [t.task_arn for t in tasks]})
+        return ActionResult({"taskArns": [t.task_arn for t in tasks]})
 
-    def stop_task(self) -> str:
+    def stop_task(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         task = self._get_param("task")
         reason = self._get_param("reason")
         task = self.ecs_backend.stop_task(cluster_str, task, reason)
-        return json.dumps({"task": task.response_object()})
+        return ActionResult({"task": task})
 
-    def create_service(self) -> str:
+    def create_service(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         service_name = self._get_param("serviceName")
         task_definition_str = self._get_param("taskDefinition")
@@ -263,6 +297,7 @@ class EC2ContainerServiceResponse(BaseResponse):
         platform_version = self._get_param("platformVersion")
         propagate_tags = self._get_param("propagateTags") or "NONE"
         network_configuration = self._get_param("networkConfiguration")
+        role = self._get_param("role")
         service = self.ecs_backend.create_service(
             cluster_str,
             service_name,
@@ -277,52 +312,53 @@ class EC2ContainerServiceResponse(BaseResponse):
             service_registries=service_registries,
             platform_version=platform_version,
             propagate_tags=propagate_tags,
+            role_arn=role,
         )
-        return json.dumps({"service": service.response_object})
+        return ActionResult({"service": service})
 
-    def list_services(self) -> str:
+    def list_services(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         scheduling_strategy = self._get_param("schedulingStrategy")
         launch_type = self._get_param("launchType")
         service_arns = self.ecs_backend.list_services(
             cluster_str, scheduling_strategy, launch_type=launch_type
         )
-        return json.dumps({"serviceArns": service_arns})
+        return ActionResult({"serviceArns": service_arns})
 
-    def describe_services(self) -> str:
+    def describe_services(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
-        service_names = self._get_param("services")
+        service_names = self._get_param("services", [])
         services, failures = self.ecs_backend.describe_services(
             cluster_str, service_names
         )
-        resp = {
-            "services": [service.response_object for service in services],
+        include = self._get_param("include", [])
+        if "TAGS" in include:
+            self._include_in_response(DESCRIBE_SERVICES_TAGS)
+        else:
+            self._exclude_from_response(DESCRIBE_SERVICES_TAGS)
+        result = {
+            "services": services,
             "failures": failures,
         }
-        if "TAGS" in self._get_param("include", []):
-            for i, service in enumerate(services):
-                resp["services"][i]["tags"] = self.ecs_backend.list_tags_for_resource(
-                    service.arn
-                )
-        return json.dumps(resp)
+        return ActionResult(result)
 
-    def update_service(self) -> str:
-        service_properties = json.loads(self.body)
+    def update_service(self) -> ActionResult:
+        service_properties = self._get_params()
         parsed_props = {}
         for k, v in service_properties.items():
             parsed_props[camelcase_to_underscores(k)] = v
 
         service = self.ecs_backend.update_service(parsed_props)
-        return json.dumps({"service": service.response_object})
+        return ActionResult({"service": service})
 
-    def delete_service(self) -> str:
+    def delete_service(self) -> ActionResult:
         service_name = self._get_param("service")
         cluster_name = self._get_param("cluster", "default")
         force = self._get_param("force", False)
         service = self.ecs_backend.delete_service(cluster_name, service_name, force)
-        return json.dumps({"service": service.response_object})
+        return ActionResult({"service": service})
 
-    def register_container_instance(self) -> str:
+    def register_container_instance(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         instance_identity_document_str = self._get_param("instanceIdentityDocument")
         instance_identity_document = json.loads(instance_identity_document_str)
@@ -330,38 +366,36 @@ class EC2ContainerServiceResponse(BaseResponse):
         container_instance = self.ecs_backend.register_container_instance(
             cluster_str, ec2_instance_id
         )
-        return json.dumps({"containerInstance": container_instance.response_object})
+        return ActionResult({"containerInstance": container_instance})
 
-    def deregister_container_instance(self) -> str:
+    def deregister_container_instance(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         container_instance_str = self._get_param("containerInstance")
         force = self._get_param("force")
         container_instance = self.ecs_backend.deregister_container_instance(
             cluster_str, container_instance_str, force
         )
-        return json.dumps({"containerInstance": container_instance.response_object})
+        return ActionResult({"containerInstance": container_instance})
 
-    def list_container_instances(self) -> str:
+    def list_container_instances(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         container_instance_arns = self.ecs_backend.list_container_instances(cluster_str)
-        return json.dumps({"containerInstanceArns": container_instance_arns})
+        return ActionResult({"containerInstanceArns": container_instance_arns})
 
-    def describe_container_instances(self) -> str:
+    def describe_container_instances(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         list_container_instance_arns = self._get_param("containerInstances")
         container_instances, failures = self.ecs_backend.describe_container_instances(
             cluster_str, list_container_instance_arns
         )
-        return json.dumps(
+        return ActionResult(
             {
-                "failures": [ci.response_object for ci in failures],
-                "containerInstances": [
-                    ci.response_object for ci in container_instances
-                ],
+                "failures": failures,
+                "containerInstances": container_instances,
             }
         )
 
-    def update_container_instances_state(self) -> str:
+    def update_container_instances_state(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         list_container_instance_arns = self._get_param("containerInstances")
         status_str = self._get_param("status")
@@ -371,24 +405,22 @@ class EC2ContainerServiceResponse(BaseResponse):
         ) = self.ecs_backend.update_container_instances_state(
             cluster_str, list_container_instance_arns, status_str
         )
-        return json.dumps(
+        return ActionResult(
             {
-                "failures": [ci.response_object for ci in failures],
-                "containerInstances": [
-                    ci.response_object for ci in container_instances
-                ],
+                "failures": failures,
+                "containerInstances": container_instances,
             }
         )
 
-    def put_attributes(self) -> str:
+    def put_attributes(self) -> ActionResult:
         cluster_name = self._get_param("cluster")
-        attributes = self._get_param("attributes")
+        attributes = self._get_param("attributes", [])
 
         self.ecs_backend.put_attributes(cluster_name, attributes)
 
-        return json.dumps({"attributes": attributes})
+        return ActionResult({"attributes": attributes})
 
-    def list_attributes(self) -> str:
+    def list_attributes(self) -> ActionResult:
         cluster_name = self._get_param("cluster")
         attr_name = self._get_param("attributeName")
         attr_value = self._get_param("attributeValue")
@@ -406,49 +438,49 @@ class EC2ContainerServiceResponse(BaseResponse):
                 tmp_result["value"] = value
             formatted_results.append(tmp_result)
 
-        return json.dumps({"attributes": formatted_results})
+        return ActionResult({"attributes": formatted_results})
 
-    def delete_attributes(self) -> str:
+    def delete_attributes(self) -> ActionResult:
         cluster_name = self._get_param("cluster", "default")
         attributes = self._get_param("attributes")
 
         self.ecs_backend.delete_attributes(cluster_name, attributes)
 
-        return json.dumps({"attributes": attributes})
+        return ActionResult({"attributes": attributes})
 
-    def discover_poll_endpoint(self) -> str:
+    def discover_poll_endpoint(self) -> ActionResult:
         # Here are the arguments, this api is used by the ecs client so obviously no decent
         # documentation. Hence I've responded with valid but useless data
         # cluster_name = self._get_param('cluster')
         # instance = self._get_param('containerInstance')
-        return json.dumps(
+        return ActionResult(
             {"endpoint": "http://localhost", "telemetryEndpoint": "http://localhost"}
         )
 
-    def list_task_definition_families(self) -> str:
+    def list_task_definition_families(self) -> ActionResult:
         family_prefix = self._get_param("familyPrefix")
         results = self.ecs_backend.list_task_definition_families(family_prefix)
 
-        return json.dumps({"families": list(results)})
+        return ActionResult({"families": list(results)})
 
-    def list_tags_for_resource(self) -> str:
+    def list_tags_for_resource(self) -> ActionResult:
         resource_arn = self._get_param("resourceArn")
         tags = self.ecs_backend.list_tags_for_resource(resource_arn)
-        return json.dumps({"tags": tags})
+        return ActionResult({"tags": tags})
 
-    def tag_resource(self) -> str:
+    def tag_resource(self) -> ActionResult:
         resource_arn = self._get_param("resourceArn")
         tags = self._get_param("tags")
         self.ecs_backend.tag_resource(resource_arn, tags)
-        return json.dumps({})
+        return EmptyResult()
 
-    def untag_resource(self) -> str:
+    def untag_resource(self) -> ActionResult:
         resource_arn = self._get_param("resourceArn")
         tag_keys = self._get_param("tagKeys")
         self.ecs_backend.untag_resource(resource_arn, tag_keys)
-        return json.dumps({})
+        return EmptyResult()
 
-    def create_task_set(self) -> str:
+    def create_task_set(self) -> ActionResult:
         service_str = self._get_param("service")
         cluster_str = self._get_param("cluster", "default")
         task_definition = self._get_param("taskDefinition")
@@ -477,31 +509,30 @@ class EC2ContainerServiceResponse(BaseResponse):
             client_token=client_token,
             tags=tags,
         )
-        return json.dumps({"taskSet": task_set.response_object})
+        return ActionResult({"taskSet": task_set})
 
-    def describe_task_sets(self) -> str:
+    def describe_task_sets(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         service_str = self._get_param("service")
-        task_sets = self._get_param("taskSets")
-        include = self._get_param("include", [])
-        task_set_objs = self.ecs_backend.describe_task_sets(
-            cluster_str, service_str, task_sets
+        task_set_ids = self._get_param("taskSets", [])
+        task_sets = self.ecs_backend.describe_task_sets(
+            cluster_str, service_str, task_set_ids
         )
+        include = self._get_param("include", [])
+        if "TAGS" in include:
+            self._include_in_response(DESCRIBE_TASK_SETS_TAGS)
+        else:
+            self._exclude_from_response(DESCRIBE_TASK_SETS_TAGS)
+        return ActionResult({"taskSets": task_sets})
 
-        response_objs = [t.response_object for t in task_set_objs]
-        if "TAGS" not in include:
-            for ro in response_objs:
-                del ro["tags"]
-        return json.dumps({"taskSets": response_objs})
-
-    def delete_task_set(self) -> str:
+    def delete_task_set(self) -> ActionResult:
         cluster_str = self._get_param("cluster")
         service_str = self._get_param("service")
         task_set = self._get_param("taskSet")
         task_set = self.ecs_backend.delete_task_set(cluster_str, service_str, task_set)
-        return json.dumps({"taskSet": task_set.response_object})
+        return ActionResult({"taskSet": task_set})
 
-    def update_task_set(self) -> str:
+    def update_task_set(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         service_str = self._get_param("service")
         task_set = self._get_param("taskSet")
@@ -510,9 +541,9 @@ class EC2ContainerServiceResponse(BaseResponse):
         task_set = self.ecs_backend.update_task_set(
             cluster_str, service_str, task_set, scale
         )
-        return json.dumps({"taskSet": task_set.response_object})
+        return ActionResult({"taskSet": task_set})
 
-    def update_service_primary_task_set(self) -> str:
+    def update_service_primary_task_set(self) -> ActionResult:
         cluster_str = self._get_param("cluster", "default")
         service_str = self._get_param("service")
         primary_task_set = self._get_param("primaryTaskSet")
@@ -520,21 +551,33 @@ class EC2ContainerServiceResponse(BaseResponse):
         task_set = self.ecs_backend.update_service_primary_task_set(
             cluster_str, service_str, primary_task_set
         )
-        return json.dumps({"taskSet": task_set.response_object})
+        return ActionResult({"taskSet": task_set})
 
-    def put_account_setting(self) -> str:
+    def put_account_setting(self) -> ActionResult:
         name = self._get_param("name")
         value = self._get_param("value")
         account_setting = self.ecs_backend.put_account_setting(name, value)
-        return json.dumps({"setting": account_setting.response_object})
+        return ActionResult({"setting": account_setting})
 
-    def list_account_settings(self) -> str:
+    def list_account_settings(self) -> ActionResult:
         name = self._get_param("name")
         value = self._get_param("value")
         account_settings = self.ecs_backend.list_account_settings(name, value)
-        return json.dumps({"settings": [s.response_object for s in account_settings]})
+        return ActionResult({"settings": account_settings})
 
-    def delete_account_setting(self) -> str:
+    def delete_account_setting(self) -> ActionResult:
         name = self._get_param("name")
         self.ecs_backend.delete_account_setting(name)
-        return "{}"
+        return EmptyResult()
+
+    def delete_task_definitions(self) -> ActionResult:
+        task_definitions = self._get_param("taskDefinitions")
+        deleted_task_definitions, failures = self.ecs_backend.delete_task_definitions(
+            task_definitions=task_definitions,
+        )
+        return ActionResult(
+            {
+                "taskDefinitions": deleted_task_definitions,
+                "failures": failures,
+            }
+        )
