@@ -1,7 +1,8 @@
 import json
 import re
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Pattern
+from re import Pattern
+from typing import Any, Optional
 
 from dateutil.tz import tzlocal
 
@@ -11,18 +12,23 @@ from moto.core.common_models import CloudFormationModel
 from moto.core.utils import iso_8601_datetime_with_milliseconds
 from moto.moto_api._internal import mock_random
 from moto.utilities.paginator import paginate
+from moto.utilities.tagging_service import TaggingService
 from moto.utilities.utils import ARN_PARTITION_REGEX, get_partition
 
 from .exceptions import (
+    ActivityAlreadyExists,
+    ActivityDoesNotExist,
     ExecutionAlreadyExists,
     ExecutionDoesNotExist,
     InvalidArn,
+    InvalidEncryptionConfiguration,
     InvalidExecutionInput,
     InvalidName,
     NameTooLongException,
     ResourceNotFound,
     StateMachineDoesNotExist,
 )
+from .parser.api import EncryptionType
 from .utils import PAGINATION_MODEL, api_to_cfn_tags, cfn_to_api_tags
 
 
@@ -33,9 +39,9 @@ class StateMachineInstance:
         name: str,
         definition: str,
         roleArn: str,
-        encryptionConfiguration: Optional[Dict[str, Any]] = None,
-        loggingConfiguration: Optional[Dict[str, Any]] = None,
-        tracingConfiguration: Optional[Dict[str, Any]] = None,
+        encryptionConfiguration: Optional[dict[str, Any]] = None,
+        loggingConfiguration: Optional[dict[str, Any]] = None,
+        tracingConfiguration: Optional[dict[str, Any]] = None,
     ):
         self.creation_date = iso_8601_datetime_with_milliseconds()
         self.update_date = self.creation_date
@@ -43,7 +49,7 @@ class StateMachineInstance:
         self.name = name
         self.definition = definition
         self.roleArn = roleArn
-        self.executions: List[Execution] = []
+        self.executions: list[Execution] = []
         self.type = "STANDARD"
         self.encryptionConfiguration = encryptionConfiguration or {
             "type": "AWS_OWNED_KEY"
@@ -81,10 +87,10 @@ class StateMachine(StateMachineInstance, CloudFormationModel):
         name: str,
         definition: str,
         roleArn: str,
-        tags: Optional[List[Dict[str, str]]] = None,
-        encryptionConfiguration: Optional[Dict[str, Any]] = None,
-        loggingConfiguration: Optional[Dict[str, Any]] = None,
-        tracingConfiguration: Optional[Dict[str, Any]] = None,
+        backend: "StepFunctionBackend",
+        encryptionConfiguration: Optional[dict[str, Any]] = None,
+        loggingConfiguration: Optional[dict[str, Any]] = None,
+        tracingConfiguration: Optional[dict[str, Any]] = None,
     ):
         StateMachineInstance.__init__(
             self,
@@ -96,13 +102,10 @@ class StateMachine(StateMachineInstance, CloudFormationModel):
             loggingConfiguration=loggingConfiguration,
             tracingConfiguration=tracingConfiguration,
         )
-        self.tags: List[Dict[str, str]] = []
-        if tags:
-            self.add_tags(tags)
-
         self.latest_version_number = 0
-        self.versions: Dict[int, StateMachineVersion] = {}
+        self.versions: dict[int, StateMachineVersion] = {}
         self.latest_version: Optional[StateMachineVersion] = None
+        self.backend = backend
 
     def publish(self, description: Optional[str]) -> None:
         new_version_number = self.latest_version_number + 1
@@ -120,15 +123,21 @@ class StateMachine(StateMachineInstance, CloudFormationModel):
         execution_name: str,
         execution_input: str,
     ) -> "Execution":
-        self._ensure_execution_name_doesnt_exist(execution_name)
         self._validate_execution_input(execution_input)
+        existing_execution = self._handle_name_input_idempotency(
+            execution_name, execution_input
+        )
+        if existing_execution is not None:
+            # If we found a match for the name and input, return the existing execution.
+            return existing_execution
+
         execution = Execution(
             region_name=region_name,
             account_id=account_id,
             state_machine_name=self.name,
             execution_name=execution_name,
             state_machine_arn=self.arn,
-            execution_input=json.loads(execution_input),
+            execution_input=execution_input,
         )
         self.executions.append(execution)
         return execution
@@ -144,12 +153,23 @@ class StateMachine(StateMachineInstance, CloudFormationModel):
         execution.stop(stop_date=datetime.now(), error="", cause="")
         return execution
 
-    def _ensure_execution_name_doesnt_exist(self, name: str) -> None:
+    def _handle_name_input_idempotency(
+        self, name: str, execution_input: str
+    ) -> Optional["Execution"]:
         for execution in self.executions:
             if execution.name == name:
+                # Executions with the same name and input are considered idempotent
+                if (
+                    execution_input == execution.execution_input
+                    and execution.status == "RUNNING"
+                ):
+                    return execution
+
+                # If the inputs are different _or_ the execution already finished, raise
                 raise ExecutionAlreadyExists(
                     "Execution Already Exists: '" + execution.execution_arn + "'"
                 )
+        return None
 
     def _validate_execution_input(self, execution_input: str) -> None:
         try:
@@ -165,32 +185,11 @@ class StateMachine(StateMachineInstance, CloudFormationModel):
                 setattr(self, key, value)
         self.update_date = iso_8601_datetime_with_milliseconds()
 
-    def add_tags(self, tags: List[Dict[str, str]]) -> List[Dict[str, str]]:
-        merged_tags = []
-        for tag in self.tags:
-            replacement_index = next(
-                (index for (index, d) in enumerate(tags) if d["key"] == tag["key"]),
-                None,
-            )
-            if replacement_index is not None:
-                replacement = tags.pop(replacement_index)
-                merged_tags.append(replacement)
-            else:
-                merged_tags.append(tag)
-        for tag in tags:
-            merged_tags.append(tag)
-        self.tags = merged_tags
-        return self.tags
-
-    def remove_tags(self, tag_keys: List[str]) -> List[Dict[str, str]]:
-        self.tags = [tag_set for tag_set in self.tags if tag_set["key"] not in tag_keys]
-        return self.tags
-
     @property
     def physical_resource_id(self) -> str:
         return self.arn
 
-    def get_cfn_properties(self, prop_overrides: Dict[str, Any]) -> Dict[str, Any]:
+    def get_cfn_properties(self, prop_overrides: dict[str, Any]) -> dict[str, Any]:
         property_names = [
             "DefinitionString",
             "RoleArn",
@@ -231,7 +230,9 @@ class StateMachine(StateMachineInstance, CloudFormationModel):
         elif attribute_name == "StateMachineName":
             return self.name
         elif attribute_name == "Tags":
-            return api_to_cfn_tags(self.tags)
+            return api_to_cfn_tags(
+                self.backend.get_tags_list_for_state_machine(self.arn)
+            )
 
         raise UnformattedGetAttTemplateException()
 
@@ -304,7 +305,7 @@ class StateMachine(StateMachineInstance, CloudFormationModel):
             state_machine = sf_backend.update_state_machine(
                 original_resource.arn, definition=definition, role_arn=role_arn
             )
-            state_machine.add_tags(tags)
+            sf_backend.tag_resource(state_machine.arn, tags)
             return state_machine
 
 
@@ -344,7 +345,7 @@ class Execution:
         self.cause: Optional[str] = None
         self.error: Optional[str] = None
 
-    def get_execution_history(self, roleArn: str) -> List[Dict[str, Any]]:
+    def get_execution_history(self, roleArn: str) -> list[dict[str, Any]]:
         sf_execution_history_type = settings.get_sf_execution_history_type()
         if sf_execution_history_type == "SUCCESS":
             return [
@@ -448,6 +449,21 @@ class Execution:
         self.stop_date = datetime.now()
 
 
+class Activity:
+    def __init__(
+        self,
+        arn: str,
+        name: str,
+        encryption_configuration: Optional[dict[str, Any]] = None,
+    ):
+        self.arn = arn
+        self.name = name
+        self.encryption_configuration = encryption_configuration
+
+        self.creation_date = iso_8601_datetime_with_milliseconds()
+        self.update_date = self.creation_date
+
+
 class StepFunctionBackend(BaseBackend):
     """
     Configure Moto to explicitly parse and execute the StateMachine:
@@ -576,10 +592,19 @@ class StepFunctionBackend(BaseBackend):
         ARN_PARTITION_REGEX
         + r":states:[-0-9a-zA-Z]+:(?P<account_id>[0-9]{12}):execution:.+"
     )
+    accepted_activity_arn_format = re.compile(
+        ARN_PARTITION_REGEX
+        + r":states:[-0-9a-zA-Z]+:(?P<account_id>[0-9]{12}):activity:.+"
+    )
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.state_machines: List[StateMachine] = []
+        self.tagger = TaggingService(
+            tag_name="tags", key_name="key", value_name="value"
+        )
+
+        self.state_machines: list[StateMachine] = []
+        self.activities: dict[str, Activity] = {}
         self._account_id = None
 
     def create_state_machine(
@@ -587,11 +612,11 @@ class StepFunctionBackend(BaseBackend):
         name: str,
         definition: str,
         roleArn: str,
-        tags: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
         publish: Optional[bool] = None,
-        loggingConfiguration: Optional[Dict[str, Any]] = None,
-        tracingConfiguration: Optional[Dict[str, Any]] = None,
-        encryptionConfiguration: Optional[Dict[str, Any]] = None,
+        loggingConfiguration: Optional[dict[str, Any]] = None,
+        tracingConfiguration: Optional[dict[str, Any]] = None,
+        encryptionConfiguration: Optional[dict[str, Any]] = None,
         version_description: Optional[str] = None,
     ) -> StateMachine:
         self._validate_name(name)
@@ -605,18 +630,22 @@ class StepFunctionBackend(BaseBackend):
                 name,
                 definition,
                 roleArn,
-                tags,
+                self,
                 encryptionConfiguration,
                 loggingConfiguration,
                 tracingConfiguration,
             )
             if publish:
                 state_machine.publish(description=version_description)
+
+            if tags:
+                self.tag_resource(arn, tags)
+
             self.state_machines.append(state_machine)
             return state_machine
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_state_machines(self) -> List[StateMachine]:
+    def list_state_machines(self) -> list[StateMachine]:
         return sorted(self.state_machines, key=lambda x: x.creation_date)
 
     def describe_state_machine(self, arn: str) -> StateMachine:
@@ -650,14 +679,14 @@ class StepFunctionBackend(BaseBackend):
         arn: str,
         definition: Optional[str] = None,
         role_arn: Optional[str] = None,
-        logging_configuration: Optional[Dict[str, bool]] = None,
-        tracing_configuration: Optional[Dict[str, bool]] = None,
-        encryption_configuration: Optional[Dict[str, Any]] = None,
+        logging_configuration: Optional[dict[str, bool]] = None,
+        tracing_configuration: Optional[dict[str, bool]] = None,
+        encryption_configuration: Optional[dict[str, Any]] = None,
         publish: Optional[bool] = None,
         version_description: Optional[str] = None,
     ) -> StateMachine:
         sm = self.describe_state_machine(arn)
-        updates: Dict[str, Any] = {
+        updates: dict[str, Any] = {
             "definition": definition,
             "roleArn": role_arn,
         }
@@ -693,7 +722,7 @@ class StepFunctionBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_executions(
         self, state_machine_arn: str, status_filter: Optional[str] = None
-    ) -> List[Execution]:
+    ) -> list[Execution]:
         executions = self.describe_state_machine(state_machine_arn).executions
 
         if status_filter:
@@ -714,7 +743,7 @@ class StepFunctionBackend(BaseBackend):
             )
         return exctn
 
-    def get_execution_history(self, execution_arn: str) -> Dict[str, Any]:
+    def get_execution_history(self, execution_arn: str) -> dict[str, Any]:
         self._validate_execution_arn(execution_arn)
         state_machine = self._get_state_machine_for_execution(execution_arn)
         execution = next(
@@ -734,26 +763,17 @@ class StepFunctionBackend(BaseBackend):
                     return sm
         raise ResourceNotFound(execution_arn)
 
-    def list_tags_for_resource(self, arn: str) -> List[Dict[str, str]]:
-        try:
-            state_machine = self.describe_state_machine(arn)
-            return state_machine.tags or []
-        except StateMachineDoesNotExist:
-            return []
+    def list_tags_for_resource(self, arn: str) -> dict[str, list[dict[str, str]]]:
+        return self.tagger.list_tags_for_resource(arn)
 
-    def tag_resource(self, resource_arn: str, tags: List[Dict[str, str]]) -> None:
-        try:
-            state_machine = self.describe_state_machine(resource_arn)
-            state_machine.add_tags(tags)
-        except StateMachineDoesNotExist:
-            raise ResourceNotFound(resource_arn)
+    def tag_resource(self, resource_arn: str, tags: list[dict[str, str]]) -> None:
+        self.tagger.tag_resource(resource_arn, tags)
 
-    def untag_resource(self, resource_arn: str, tag_keys: List[str]) -> None:
-        try:
-            state_machine = self.describe_state_machine(resource_arn)
-            state_machine.remove_tags(tag_keys)
-        except StateMachineDoesNotExist:
-            raise ResourceNotFound(resource_arn)
+    def untag_resource(self, resource_arn: str, tag_keys: list[str]) -> None:
+        self.tagger.untag_resource_using_names(resource_arn, tag_keys)
+
+    def get_tags_list_for_state_machine(self, arn: str) -> list[dict[str, str]]:
+        return self.list_tags_for_resource(arn)[self.tagger.tag_name]
 
     def send_task_failure(self, task_token: str, error: Optional[str] = None) -> None:
         pass
@@ -764,7 +784,7 @@ class StepFunctionBackend(BaseBackend):
     def send_task_success(self, task_token: str, outcome: str) -> None:
         pass
 
-    def describe_map_run(self, map_run_arn: str) -> Dict[str, Any]:
+    def describe_map_run(self, map_run_arn: str) -> dict[str, Any]:
         return {}
 
     def list_map_runs(self, execution_arn: str) -> Any:
@@ -810,11 +830,35 @@ class StepFunctionBackend(BaseBackend):
             invalid_msg="Execution Does Not Exist: '" + execution_arn + "'",
         )
 
+    def _validate_activity_arn(self, activity_arn: str) -> None:
+        self._validate_arn(
+            arn=activity_arn,
+            regex=self.accepted_activity_arn_format,
+            invalid_msg="Invalid Activity Arn: '" + activity_arn + "'",
+        )
+
     def _validate_arn(self, arn: str, regex: Pattern[str], invalid_msg: str) -> None:
         match = regex.match(arn)
         if not arn or not match:
             raise InvalidArn(invalid_msg)
 
+    def _validate_encryption_configuration(
+        self, encryption_configuration: dict[str, Any]
+    ) -> None:
+        encryption_type = encryption_configuration.get("type")
+        if not encryption_type:
+            raise InvalidEncryptionConfiguration(
+                "Invalid Encryption Configuration: 'type' is required."
+            )
+
+        if (
+            encryption_type == EncryptionType.CUSTOMER_MANAGED_KMS_KEY
+            and not encryption_configuration.get("kmsKeyId")
+        ):
+            raise InvalidEncryptionConfiguration(
+                "Invalid Encryption Configuration: 'kmsKeyId' is required when 'type' is 'CUSTOMER_MANAGED_KMS_KEY'"
+            )
+
     def _get_state_machine_for_execution(self, execution_arn: str) -> StateMachine:
         state_machine_name = execution_arn.split(":")[6]
         state_machine_arn = next(
@@ -828,5 +872,49 @@ class StepFunctionBackend(BaseBackend):
             )
         return self.describe_state_machine(state_machine_arn)
 
+    def create_activity(
+        self,
+        name: str,
+        tags: Optional[list[dict[str, str]]] = None,
+        encryption_configuration: Optional[dict[str, Any]] = None,
+    ) -> Activity:
+        self._validate_name(name)
+
+        if encryption_configuration is not None:
+            self._validate_encryption_configuration(encryption_configuration)
+
+        arn = f"arn:{get_partition(self.region_name)}:states:{self.region_name}:{self.account_id}:activity:{name}"
+
+        if arn in self.activities:
+            raise ActivityAlreadyExists("Activity already exists.")
+
+        activity = Activity(
+            arn=arn,
+            name=name,
+            encryption_configuration=encryption_configuration,
+        )
+        self.activities[arn] = activity
+
+        if tags:
+            self.tag_resource(arn, tags)
+
+        return activity
+
+    def describe_activity(self, activity_arn: str) -> Activity:
+        self._validate_activity_arn(activity_arn)
+        if activity_arn in self.activities:
+            return self.activities[activity_arn]
+        else:
+            raise ActivityDoesNotExist(activity_arn)
+
+    def delete_activity(self, activity_arn: str) -> None:
+        self._validate_activity_arn(activity_arn)
+        if activity_arn in self.activities:
+            del self.activities[activity_arn]
+
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def list_activities(self) -> list[Activity]:
+        return sorted(self.activities.values(), key=lambda x: x.creation_date)
+
 
 stepfunctions_backends = BackendDict(StepFunctionBackend, "stepfunctions")
