@@ -1,4 +1,4 @@
-from typing import Final, List
+from typing import Final
 
 from moto.stepfunctions.parser.asl.component.common.payload.payloadvalue.payload_value import (
     PayloadValue,
@@ -10,10 +10,10 @@ from moto.stepfunctions.parser.asl.eval.environment import Environment
 
 
 class PayloadTmpl(PayloadValue):
-    def __init__(self, payload_bindings: List[PayloadBinding]):
-        self.payload_bindings: Final[List[PayloadBinding]] = payload_bindings
+    def __init__(self, payload_bindings: list[PayloadBinding]):
+        self.payload_bindings: Final[list[PayloadBinding]] = payload_bindings
 
     def _eval_body(self, env: Environment) -> None:
-        env.stack.append(dict())
+        env.stack.append({})
         for payload_binding in self.payload_bindings:
             payload_binding.eval(env)
