@@ -1,6 +1,5 @@
-from moto.moto_api._internal import mock_random
-from moto.stepfunctions.parser.asl.component.intrinsic.argument.function_argument_list import (
-    FunctionArgumentList,
+from moto.stepfunctions.parser.asl.component.intrinsic.argument.argument import (
+    ArgumentList,
 )
 from moto.stepfunctions.parser.asl.component.intrinsic.function.statesfunction.states_function import (
     StatesFunction,
@@ -12,18 +11,19 @@ from moto.stepfunctions.parser.asl.component.intrinsic.functionname.states_funct
     StatesFunctionName,
 )
 from moto.stepfunctions.parser.asl.eval.environment import Environment
+from moto.stepfunctions.parser.utils import long_uid
 
 
 class UUID(StatesFunction):
-    def __init__(self, arg_list: FunctionArgumentList):
+    def __init__(self, argument_list: ArgumentList):
         super().__init__(
             states_name=StatesFunctionName(function_type=StatesFunctionNameType.UUID),
-            arg_list=arg_list,
+            argument_list=argument_list,
         )
-        if len(arg_list.arg_list) != 0:
+        if argument_list.size != 0:
             raise ValueError(
-                f"Expected no arguments for function type '{type(self)}', but got: '{arg_list}'."
+                f"Expected no arguments for function type '{type(self)}', but got: '{argument_list}'."
             )
 
     def _eval_body(self, env: Environment) -> None:
-        env.stack.append(str(mock_random.uuid4()))
+        env.stack.append(long_uid())
