@@ -1,4 +1,4 @@
-from typing import Final, List
+from typing import Final
 
 from moto.stepfunctions.parser.asl.component.component import Component
 from moto.stepfunctions.parser.asl.component.state.choice.choice_rule import (
@@ -7,5 +7,5 @@ from moto.stepfunctions.parser.asl.component.state.choice.choice_rule import (
 
 
 class ChoicesDecl(Component):
-    def __init__(self, rules: List[ChoiceRule]):
-        self.rules: Final[List[ChoiceRule]] = rules
+    def __init__(self, rules: list[ChoiceRule]):
+        self.rules: Final[list[ChoiceRule]] = rules
