@@ -1,4 +1,4 @@
-from typing import Dict, Optional, Set, Tuple
+from typing import Final, Optional
 
 from botocore.exceptions import ClientError
 
@@ -10,7 +10,7 @@ from moto.stepfunctions.parser.asl.component.common.error_name.failure_event imp
     FailureEvent,
 )
 from moto.stepfunctions.parser.asl.component.state.exec.state_task.credentials import (
-    ComputedCredentials,
+    StateCredentials,
 )
 from moto.stepfunctions.parser.asl.component.state.exec.state_task.service.resource import (
     ResourceRuntimePart,
@@ -22,9 +22,9 @@ from moto.stepfunctions.parser.asl.eval.environment import Environment
 from moto.stepfunctions.parser.asl.eval.event.event_detail import EventDetails
 from moto.stepfunctions.parser.asl.utils.boto_client import boto_client_for
 
-_ERROR_NAME_AWS: str = "DynamoDB.AmazonDynamoDBException"
+_ERROR_NAME_AWS: Final[str] = "DynamoDB.AmazonDynamoDBException"
 
-_SUPPORTED_API_PARAM_BINDINGS: Dict[str, Set[str]] = {
+_SUPPORTED_API_PARAM_BINDINGS: Final[dict[str, set[str]]] = {
     "getitem": {
         "Key",
         "TableName",
@@ -76,11 +76,11 @@ _SUPPORTED_API_PARAM_BINDINGS: Dict[str, Set[str]] = {
 
 
 class StateTaskServiceDynamoDB(StateTaskService):
-    def _get_supported_parameters(self) -> Optional[Set[str]]:
+    def _get_supported_parameters(self) -> Optional[set[str]]:
         return _SUPPORTED_API_PARAM_BINDINGS.get(self.resource.api_action.lower())
 
     @staticmethod
-    def _error_cause_from_client_error(client_error: ClientError) -> Tuple[str, str]:
+    def _error_cause_from_client_error(client_error: ClientError) -> tuple[str, str]:
         error_code: str = client_error.response["Error"]["Code"]
         error_msg: str = client_error.response["Error"]["Message"]
         response_details = "; ".join(
@@ -133,15 +133,14 @@ class StateTaskServiceDynamoDB(StateTaskService):
         env: Environment,
         resource_runtime_part: ResourceRuntimePart,
         normalised_parameters: dict,
-        task_credentials: ComputedCredentials,
+        state_credentials: StateCredentials,
     ):
         service_name = self._get_boto_service_name()
         api_action = self._get_boto_service_action()
         dynamodb_client = boto_client_for(
-            region=resource_runtime_part.region,
-            account=resource_runtime_part.account,
             service=service_name,
-            credentials=task_credentials,
+            region=resource_runtime_part.region,
+            state_credentials=state_credentials,
         )
         response = getattr(dynamodb_client, api_action)(**normalised_parameters)
         response.pop("ResponseMetadata", None)
