@@ -6,12 +6,16 @@ import requests
 
 from moto import mock_aws, settings
 from moto.core.models import responses_mock
+from moto.core.versions import is_responses_0_17_x
 
 
 @mock_aws
 def test_http_integration():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cannot test mock of execute-api.apigateway in ServerMode")
+    if not is_responses_0_17_x():
+        raise SkipTest("Not supported in older requests-version")
+
     responses_mock.add(
         responses_mock.GET, "http://httpbin.org/robots.txt", body="a fake response"
     )
@@ -59,6 +63,8 @@ def test_http_integration():
 def test_aws_integration_dynamodb():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cannot test mock of execute-api.apigateway in ServerMode")
+    if not is_responses_0_17_x():
+        raise SkipTest("Not supported in older requests-version")
 
     client = boto3.client("apigateway", region_name="us-west-2")
     dynamodb = boto3.client("dynamodb", region_name="us-west-2")
@@ -83,6 +89,8 @@ def test_aws_integration_dynamodb():
 def test_aws_integration_dynamodb_multiple_stages():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cannot test mock of execute-api.apigateway in ServerMode")
+    if not is_responses_0_17_x():
+        raise SkipTest("Not supported in older requests-version")
 
     client = boto3.client("apigateway", region_name="us-west-2")
     dynamodb = boto3.client("dynamodb", region_name="us-west-2")
@@ -119,6 +127,8 @@ def test_aws_integration_dynamodb_multiple_stages():
 def test_aws_integration_dynamodb_multiple_resources():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cannot test mock of execute-api.apigateway in ServerMode")
+    if not is_responses_0_17_x():
+        raise SkipTest("Not supported in older requests-version")
 
     client = boto3.client("apigateway", region_name="us-west-2")
     dynamodb = boto3.client("dynamodb", region_name="us-west-2")
