@@ -382,17 +382,17 @@ def test_create_function__with_tracingmode(tracing_mode):
     source, output = tracing_mode
     zip_content = get_test_zip_file1()
     function_name = str(uuid4())[0:6]
-    kwargs = dict(
-        FunctionName=function_name,
-        Runtime=PYTHON_VERSION,
-        Role=get_role_name(),
-        Handler="lambda_function.lambda_handler",
-        Code={"ZipFile": zip_content},
-        Description="test lambda function",
-        Timeout=3,
-        MemorySize=128,
-        Publish=True,
-    )
+    kwargs = {
+        "FunctionName": function_name,
+        "Runtime": PYTHON_VERSION,
+        "Role": get_role_name(),
+        "Handler": "lambda_function.lambda_handler",
+        "Code": {"ZipFile": zip_content},
+        "Description": "test lambda function",
+        "Timeout": 3,
+        "MemorySize": 128,
+        "Publish": True,
+    }
     if source:
         kwargs["TracingConfig"] = {"Mode": source}
     result = conn.create_function(**kwargs)
@@ -454,7 +454,7 @@ def test_create_function_from_stubbed_ecr():
 @mock_aws
 def test_create_function_from_mocked_ecr_image_tag(
     with_ecr_mock,
-):  # pylint: disable=unused-argument
+):
     if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
         raise SkipTest("Parameters only available in newer versions")
     if not settings.TEST_DECORATOR_MODE:
@@ -498,7 +498,7 @@ def test_create_function_from_mocked_ecr_image_tag(
 @mock_aws
 def test_create_function_from_mocked_ecr_image_digest(
     with_ecr_mock,
-):  # pylint: disable=unused-argument
+):
     if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
         raise SkipTest("Parameters only available in newer versions")
     if not settings.TEST_DECORATOR_MODE:
@@ -527,7 +527,7 @@ def test_create_function_from_mocked_ecr_image_digest(
 @mock_aws
 def test_create_function_from_mocked_ecr_missing_image(
     with_ecr_mock,
-):  # pylint: disable=unused-argument
+):
     if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
         raise SkipTest("Parameters only available in newer versions")
     if not settings.TEST_DECORATOR_MODE:
