@@ -1,12 +1,16 @@
 import json
+import sys
 import time
 import uuid
+from unittest import SkipTest
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 
 from moto import mock_aws
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from moto.utilities.distutils_version import LooseVersion
 
 from ..markers import requires_docker
 from .utilities import (
@@ -18,10 +22,14 @@ from .utilities import (
 
 PYTHON_VERSION = "python3.11"
 _lambda_region = "us-west-2"
+botocore_version = sys.modules["botocore"].__version__
 
 
 @mock_aws
 def test_create_event_source_mapping():
+    if LooseVersion(botocore_version) < LooseVersion("1.23.12"):
+        raise SkipTest("Parameter FilterCriteria is not available in older versions")
+
     function_name = str(uuid.uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
@@ -116,6 +124,10 @@ def test_create_event_source_mapping():
         "MinimumPollers": 12,
         "MaximumPollers": 13,
     }
+    expected_esm_arn = (
+        f"arn:aws:lambda:us-east-1:{ACCOUNT_ID}:event-source-mapping:{response['UUID']}"
+    )
+    assert response["EventSourceMappingArn"] == expected_esm_arn
 
 
 @pytest.mark.network
@@ -212,7 +224,7 @@ def test_invoke_function_from_dynamodb_put():
         expected_msg + " was not found after a DDB insert. All logs: " + str(all_logs)
     )
     assert any(
-        [json.dumps(item_to_create, separators=(",", ":")) in msg for msg in all_logs]
+        json.dumps(item_to_create, separators=(",", ":")) in msg for msg in all_logs
     )
 
 
@@ -271,9 +283,9 @@ def test_invoke_function_from_dynamodb_update():
         expected_msg + " was not found after updating DDB. All logs: " + str(all_logs)
     )
     assert "Nr_of_records(1)" in all_logs, "Only one item should be updated"
-    assert (
-        "Nr_of_records(2)" not in all_logs
-    ), "The inserted item should not show up again"
+    assert "Nr_of_records(2)" not in all_logs, (
+        "The inserted item should not show up again"
+    )
 
 
 @pytest.mark.network
@@ -336,7 +348,7 @@ def test_invoke_function_from_sqs_exception():
                 return
         time.sleep(1)
 
-    assert False, "Test Failed"
+    raise AssertionError("Test Failed")
 
 
 @pytest.mark.network
@@ -393,7 +405,7 @@ def test_invoke_function_from_sns():
 
         time.sleep(1)
 
-    assert False, "Expected message not found in logs:" + str(events)
+    raise AssertionError("Expected message not found in logs:" + str(events))
 
 
 @pytest.mark.network
@@ -449,7 +461,7 @@ def test_invoke_function_from_kinesis():
 
         time.sleep(0.5)
 
-    assert False, "Expected message not found in logs:" + str(events)
+    raise AssertionError("Expected message not found in logs:" + str(events))
 
 
 @mock_aws
@@ -518,6 +530,9 @@ def test_get_event_source_mapping():
 
 @mock_aws
 def test_update_event_source_mapping():
+    if LooseVersion(botocore_version) < LooseVersion("1.23.12"):
+        raise SkipTest("Parameter FilterCriteria is not available in older versions")
+
     function_name = str(uuid.uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
@@ -647,3 +662,42 @@ def test_delete_event_source_mapping():
     err = exc.value.response["Error"]
     assert err["Code"] == "ResourceNotFoundException"
     assert err["Message"] == "The resource you requested does not exist."
+
+
+@mock_aws
+def test_event_source_mapping_tagging_lifecycle():
+    if LooseVersion(botocore_version) < LooseVersion("1.35.23"):
+        raise SkipTest(
+            "Tagging support for Lambda event source mapping is not available in older Botocore versions"
+        )
+
+    iam = boto3.client("iam", region_name="us-east-1")
+    iam_role = iam.create_role(RoleName="role", AssumeRolePolicyDocument="{}")
+    client = boto3.client("lambda", region_name="us-east-1")
+    client.create_function(
+        FunctionName="any-function-name",
+        Runtime="python3.6",
+        Role=iam_role["Role"]["Arn"],
+        Handler="any-handler",
+        Code={
+            "ZipFile": b"any zip file",
+        },
+    )
+    sqs = boto3.client("sqs", region_name="us-east-1")
+    queue_url = sqs.create_queue(QueueName="any-queue-name")
+    queue_arn = sqs.get_queue_attributes(
+        QueueUrl=queue_url["QueueUrl"], AttributeNames=["QueueArn"]
+    )["Attributes"]["QueueArn"]
+    event_source_mapping = client.create_event_source_mapping(
+        FunctionName="any-function-name",
+        EventSourceArn=queue_arn,
+    )
+    esm_arn = event_source_mapping["EventSourceMappingArn"]
+    tags = {"foo": "bar", "baz": "qux"}
+    client.tag_resource(Resource=esm_arn, Tags=tags)
+    resp = client.list_tags(Resource=esm_arn)
+    for key, value in tags.items():
+        assert resp["Tags"][key] == value
+    client.untag_resource(Resource=esm_arn, TagKeys=["foo"])
+    resp = client.list_tags(Resource=esm_arn)
+    assert resp["Tags"] == {"baz": "qux"}
