@@ -7,6 +7,8 @@ from botocore.client import ClientError
 from moto import mock_aws, settings
 from tests import EXAMPLE_AMI_ID
 
+from .helpers import assert_dryrun_error
+
 
 @mock_aws
 def test_launch_template_create():
@@ -66,12 +68,7 @@ def test_create_launch_template__dryrun():
                 {"ResourceType": "instance", "Tags": [{"Key": "key", "Value": "value"}]}
             ],
         )
-    err = exc.value.response["Error"]
-    assert err["Code"] == "DryRunOperation"
-    assert (
-        err["Message"]
-        == "An error occurred (DryRunOperation) when calling the CreateLaunchTemplate operation: Request would have succeeded, but DryRun flag is set"
-    )
+    assert_dryrun_error(exc)
 
 
 @mock_aws
@@ -189,12 +186,7 @@ def test_create_launch_template_version__dryrun():
             LaunchTemplateData={"ImageId": "ami-def456"},
             VersionDescription="new ami",
         )
-    err = exc.value.response["Error"]
-    assert err["Code"] == "DryRunOperation"
-    assert (
-        err["Message"]
-        == "An error occurred (DryRunOperation) when calling the CreateLaunchTemplateVersion operation: Request would have succeeded, but DryRun flag is set"
-    )
+    assert_dryrun_error(exc)
 
 
 @mock_aws
@@ -568,12 +560,7 @@ def test_delete_launch_template__dryrun():
 
     with pytest.raises(ClientError) as exc:
         cli.delete_launch_template(DryRun=True, LaunchTemplateName=template_name)
-    err = exc.value.response["Error"]
-    assert err["Code"] == "DryRunOperation"
-    assert (
-        err["Message"]
-        == "An error occurred (DryRunOperation) when calling the DeleteLaunchTemplate operation: Request would have succeeded, but DryRun flag is set"
-    )
+    assert_dryrun_error(exc)
 
     # Template still exists
     assert (
@@ -670,12 +657,14 @@ def test_delete_launch_template__by_id():
     )
 
 
-def retrieve_all_templates(client, filters=[]):  # pylint: disable=W0102
-    resp = client.describe_launch_templates(Filters=filters)
+def retrieve_all_templates(client, filters=None):
+    resp = client.describe_launch_templates(Filters=filters or [])
     all_templates = resp["LaunchTemplates"]
     next_token = resp.get("NextToken")
     while next_token:
-        resp = client.describe_launch_templates(Filters=filters, NextToken=next_token)
+        resp = client.describe_launch_templates(
+            Filters=filters or [], NextToken=next_token
+        )
         all_templates.extend(resp["LaunchTemplates"])
         next_token = resp.get("NextToken")
     return all_templates
@@ -747,3 +736,47 @@ def test_launch_template_describe_with_tags():
     assert lt["LatestVersionNumber"] == 1
     assert len(lt["Tags"]) == 1
     assert lt["Tags"][0] == {"Key": "test1", "Value": "value1"}
+
+
+@mock_aws
+def test_modify_launch_template_by_name():
+    cli = boto3.client("ec2", region_name="us-east-1")
+
+    template_name = str(uuid4())
+    create_resp = cli.create_launch_template(
+        LaunchTemplateName=template_name, LaunchTemplateData={"ImageId": "ami-abc123"}
+    )
+
+    version_resp = cli.create_launch_template_version(
+        LaunchTemplateId=create_resp["LaunchTemplate"]["LaunchTemplateId"],
+        LaunchTemplateData={"ImageId": "ami-def456"},
+    )
+
+    resp = cli.modify_launch_template(
+        LaunchTemplateId=create_resp["LaunchTemplate"]["LaunchTemplateId"],
+        DefaultVersion="2",
+    )
+
+    assert "DefaultVersionNumber" in resp["LaunchTemplate"]
+    version = version_resp["LaunchTemplateVersion"]
+    assert resp["LaunchTemplate"]["DefaultVersionNumber"] == 2
+    assert (
+        version["LaunchTemplateId"] == create_resp["LaunchTemplate"]["LaunchTemplateId"]
+    )
+
+
+@mock_aws
+def test_create_launch_template_with_non_base64_encoded_user_data_fails():
+    client = boto3.client("ec2", region_name="us-east-1")
+    with pytest.raises(ClientError) as exc:
+        client.create_launch_template(
+            LaunchTemplateName="test-template",
+            LaunchTemplateData={
+                "ImageId": "ami-12345678",
+                "InstanceType": "t2.nano",
+                "UserData": "not base64 encoded",
+            },
+        )
+    error = exc.value.response["Error"]
+    assert error["Code"] == "InvalidUserData.Malformed"
+    assert error["Message"] == "Invalid BASE64 encoding of user data."
