@@ -16,10 +16,10 @@ def test_create_load_balancer():
     response, _, security_group, subnet1, subnet2, conn = create_load_balancer()
 
     lb = response["LoadBalancers"][0]
+    assert lb["CanonicalHostedZoneId"].startswith("Z")
     assert lb["DNSName"] == "my-lb-1.us-east-1.elb.amazonaws.com"
-    assert (
-        lb["LoadBalancerArn"]
-        == f"arn:aws:elasticloadbalancing:us-east-1:{ACCOUNT_ID}:loadbalancer/app/my-lb/50dc6c495c0c9188"
+    assert lb["LoadBalancerArn"].startswith(
+        f"arn:aws:elasticloadbalancing:us-east-1:{ACCOUNT_ID}:loadbalancer/app/my-lb/"
     )
     assert lb["SecurityGroups"] == [security_group.id]
     assert lb["AvailabilityZones"] == [
@@ -102,6 +102,7 @@ def test_describe_load_balancers():
 
     assert len(response["LoadBalancers"]) == 1
     lb = response["LoadBalancers"][0]
+    assert lb["CanonicalHostedZoneId"].startswith("Z")
     assert lb["LoadBalancerName"] == "my-lb"
     assert lb["State"]["Code"] == "active"
 
@@ -173,7 +174,7 @@ def test_add_remove_tags():
             ResourceArns=[lb["LoadBalancerArn"]], Tags=[{"Key": "k", "Value": "b"}]
         )
     err = exc.value.response["Error"]
-    assert err["Code"] == "TooManyTagsError"
+    assert err["Code"] == "TooManyTags"
 
     conn.add_tags(
         ResourceArns=[lb["LoadBalancerArn"]], Tags=[{"Key": "j", "Value": "c"}]
@@ -994,17 +995,26 @@ def test_handle_listener_rules():
                     "TargetGroups": [
                         {
                             "TargetGroupArn": target_group["TargetGroupArn"],
-                            "Weight": 1,
                         },
                         {
                             "TargetGroupArn": target_group["TargetGroupArn"],
-                            "Weight": 2,
+                            "Weight": 20,
                         },
                     ]
                 },
             },
         ],
     )
+    # test for default weights
+    rule_arn = rules["Rules"][0]["RuleArn"]
+    forward_rule = conn.describe_rules(RuleArns=[rule_arn])["Rules"][0]
+    assert len(forward_rule["Actions"]) == 1
+    assert len(forward_rule["Actions"][0]["ForwardConfig"]["TargetGroups"]) == 2
+    weights = [
+        tg["Weight"]
+        for tg in forward_rule["Actions"][0]["ForwardConfig"]["TargetGroups"]
+    ]
+    assert weights == [1, 20]
 
     # test for PriorityInUse
     with pytest.raises(ClientError):
@@ -1442,6 +1452,37 @@ def test_modify_load_balancer_attributes_routing_http_drop_invalid_header_fields
     assert routing_http_drop_invalid_header_fields_enabled["Value"] == "false"
 
 
+@mock_aws
+def test_modify_load_balancer_attributes_secondary_ips_auto_assigned_per_subnet():
+    response, _, _, _, _, client = create_load_balancer("network")
+    arn = response["LoadBalancers"][0]["LoadBalancerArn"]
+
+    client.modify_load_balancer_attributes(
+        LoadBalancerArn=arn,
+        Attributes=[{"Key": "secondary_ips.auto_assigned.per_subnet", "Value": "3"}],
+    )
+    response = client.describe_load_balancer_attributes(LoadBalancerArn=arn)
+    routing_http_drop_invalid_header_fields_enabled = list(
+        filter(
+            lambda item: item["Key"] == "secondary_ips.auto_assigned.per_subnet",
+            response["Attributes"],
+        )
+    )[0]
+    assert routing_http_drop_invalid_header_fields_enabled["Value"] == "3"
+
+
+@mock_aws
+def test_describe_load_balancer_attributes_default():
+    response, _, _, _, _, client = create_load_balancer()
+    arn = response["LoadBalancers"][0]["LoadBalancerArn"]
+
+    attrs = client.describe_load_balancer_attributes(LoadBalancerArn=arn)["Attributes"]
+    assert {"Key": "access_logs.s3.bucket", "Value": ""} in attrs
+    assert {"Key": "access_logs.s3.prefix", "Value": ""} in attrs
+    assert {"Key": "deletion_protection.enabled", "Value": "false"} in attrs
+    assert {"Key": "load_balancing.cross_zone.enabled", "Value": "false"} in attrs
+
+
 @mock_aws
 def test_modify_load_balancer_attributes_connection_logs_s3():
     response, _, _, _, _, client = create_load_balancer()
@@ -1456,7 +1497,6 @@ def test_modify_load_balancer_attributes_connection_logs_s3():
         ],
     )
 
-    response = client.describe_load_balancer_attributes(LoadBalancerArn=arn)
     attrs = client.describe_load_balancer_attributes(LoadBalancerArn=arn)["Attributes"]
     assert {"Key": "connection_logs.s3.enabled", "Value": "true"} in attrs
     assert {"Key": "connection_logs.s3.bucket", "Value": "s3bucket"} in attrs
@@ -1741,6 +1781,66 @@ def test_add_listener_certificate():
     assert exc.value.response["Error"]["Code"] == "TooManyCertificates"
 
 
+@mock_aws
+def test_describe_listener_certificates_with_default_field():
+    """Test that describe_listener_certificates returns IsDefault field.
+
+    The IsDefault field should be True for the default certificate and False
+    for SNI certificates.
+    """
+    client = boto3.client("elbv2", region_name="us-east-1")
+    acm = boto3.client("acm", region_name="us-east-1")
+    ec2 = boto3.resource("ec2", region_name="us-east-1")
+
+    vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
+    subnet1 = ec2.create_subnet(
+        VpcId=vpc.id, CidrBlock="10.0.1.0/24", AvailabilityZone="us-east-1a"
+    )
+    subnet2 = ec2.create_subnet(
+        VpcId=vpc.id, CidrBlock="10.0.2.0/24", AvailabilityZone="us-east-1b"
+    )
+
+    response = client.create_load_balancer(
+        Name="my-lb", Subnets=[subnet1.id, subnet2.id]
+    )
+    load_balancer_arn = response["LoadBalancers"][0]["LoadBalancerArn"]
+
+    response = client.create_target_group(
+        Name="my-tg", Protocol="HTTPS", Port=443, VpcId=vpc.id
+    )
+    target_group_arn = response["TargetGroups"][0]["TargetGroupArn"]
+
+    response = acm.request_certificate(DomainName="example.com")
+    cert_arn = response["CertificateArn"]
+
+    response = client.create_listener(
+        LoadBalancerArn=load_balancer_arn,
+        Protocol="HTTPS",
+        Port=443,
+        Certificates=[{"CertificateArn": cert_arn}],
+        DefaultActions=[{"Type": "forward", "TargetGroupArn": target_group_arn}],
+    )
+    listener_arn = response["Listeners"][0]["ListenerArn"]
+
+    client.add_listener_certificates(
+        ListenerArn=listener_arn, Certificates=[{"CertificateArn": cert_arn}]
+    )
+
+    certs = client.describe_listener_certificates(ListenerArn=listener_arn)[
+        "Certificates"
+    ]
+
+    assert len(certs) == 2
+
+    default_certs = [c for c in certs if c.get("IsDefault") is True]
+    sni_certs = [c for c in certs if c.get("IsDefault") is False]
+
+    assert len(default_certs) == 1, "Should have exactly one default certificate"
+    assert len(sni_certs) == 1, "Should have exactly one SNI certificate"
+    assert default_certs[0]["CertificateArn"] == cert_arn
+    assert sni_certs[0]["CertificateArn"] == cert_arn
+
+
 @mock_aws
 def test_forward_config_action():
     response, vpc, _, _, _, conn = create_load_balancer()
@@ -2103,3 +2203,12 @@ def test_create_listener_with_alpn_policy():
 
     describe = conn.describe_listeners(ListenerArns=[listener_arn])["Listeners"][0]
     assert describe["AlpnPolicy"] == ["pol1", "pol2"]
+
+
+@mock_aws
+def test_describe_capacity_reservation():
+    lbs, _, _, _, _, conn = create_load_balancer()
+    load_balancer_arn = lbs["LoadBalancers"][0]["LoadBalancerArn"]
+    resp = conn.describe_capacity_reservation(LoadBalancerArn=load_balancer_arn)
+    for crs in resp["CapacityReservationState"]:
+        assert crs["State"]["Code"] == "provisioned"
