@@ -7,23 +7,23 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_aws
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
-run_job_flow_args = dict(
-    Instances={
+run_job_flow_args = {
+    "Instances": {
         "InstanceCount": 3,
         "KeepJobFlowAliveWhenNoSteps": True,
         "MasterInstanceType": "c3.medium",
         "Placement": {"AvailabilityZone": "us-east-1a"},
         "SlaveInstanceType": "c3.xlarge",
     },
-    JobFlowRole="EMR_EC2_DefaultRole",
-    LogUri="s3://mybucket/log",
-    Name="cluster",
-    ServiceRole="EMR_DefaultRole",
-    VisibleToAllUsers=True,
-)
+    "JobFlowRole": "EMR_EC2_DefaultRole",
+    "LogUri": "s3://mybucket/log",
+    "Name": "cluster",
+    "ServiceRole": "EMR_DefaultRole",
+    "VisibleToAllUsers": True,
+}
 
 
 input_instance_groups = [
@@ -81,8 +81,10 @@ def test_describe_cluster():
         {
             "Classification": "yarn-site",
             "Properties": {
-                "someproperty": "somevalue",
-                "someotherproperty": "someothervalue",
+                "camelCase": "somevalue",
+                "PascalCase": "someothervalue",
+                "kebab-case": "anothervalue",
+                "snake_case": "yetanothervalue",
             },
         },
         {
@@ -91,7 +93,10 @@ def test_describe_cluster():
             "Configurations": [
                 {
                     "Classification": "nested-config",
-                    "Properties": {"nested-property": "nested-value"},
+                    "Properties": {
+                        "nested-property": "nested-value",
+                        "NestedProperty": "another-nested-value",
+                    },
                 }
             ],
         },
@@ -189,13 +194,60 @@ def test_describe_cluster():
     )
 
 
+@mock_aws
+def test_describe_cluster_master_public_dns():
+    region_name = "us-east-1" if settings.TEST_SERVER_MODE else "ap-south-1"
+
+    client = boto3.client("emr", region_name=region_name)
+
+    args = deepcopy(run_job_flow_args)
+    args["Instances"] = {"InstanceGroups": input_instance_groups}
+
+    cluster_id = client.run_job_flow(**args)["JobFlowId"]
+
+    response = client.describe_cluster(ClusterId=cluster_id)
+    master_public_dns_name = response["Cluster"]["MasterPublicDnsName"]
+    assert master_public_dns_name.startswith("ec2-")
+    assert region_name in master_public_dns_name
+    assert master_public_dns_name.endswith(".amazonaws.com")
+
+
+@mock_aws
+def test_describe_cluster_ebs_volume_fields():
+    client = boto3.client("emr", region_name="ap-south-1")
+
+    args = deepcopy(run_job_flow_args)
+
+    # Must return empty if not set in request
+    cluster_id = client.run_job_flow(**args)["JobFlowId"]
+    response = client.describe_cluster(ClusterId=cluster_id)
+    assert "EbsRootVolumeSize" not in response["Cluster"]
+    assert "EbsRootVolumeIops" not in response["Cluster"]
+    assert "EbsRootVolumeThroughput" not in response["Cluster"]
+
+    # Must return proper values when set
+    args.update(
+        {
+            "EbsRootVolumeSize": 10,
+            "EbsRootVolumeIops": 3000,
+            "EbsRootVolumeThroughput": 125,
+        }
+    )
+    cluster_id = client.run_job_flow(**args)["JobFlowId"]
+    response = client.describe_cluster(ClusterId=cluster_id)
+    assert response["Cluster"]["EbsRootVolumeSize"] == 10
+    assert response["Cluster"]["EbsRootVolumeIops"] == 3000
+    assert response["Cluster"]["EbsRootVolumeThroughput"] == 125
+
+
 @mock_aws
 def test_describe_cluster_not_found():
     conn = boto3.client("emr", region_name="us-east-1")
     with pytest.raises(ClientError) as e:
         conn.describe_cluster(ClusterId="DummyId")
-
-    assert e.value.response["Error"]["Code"] == "ResourceNotFoundException"
+    resp = e.value.response
+    assert resp["Error"]["Code"] == "InvalidRequestException"
+    assert resp["ErrorCode"] == "NoSuchCluster"
 
 
 @mock_aws
@@ -218,7 +270,6 @@ def test_describe_job_flows():
     # the nearest second internally
     time.sleep(1)
     timestamp = datetime.now(timezone.utc)
-    time.sleep(1)
 
     for idx in range(4, 6):
         cluster_name = "cluster" + str(idx)
@@ -272,7 +323,7 @@ def test_describe_job_flow():
     jf = client.describe_job_flows(JobFlowIds=[cluster_id])["JobFlows"][0]
 
     assert jf["AmiVersion"] == args["AmiVersion"]
-    assert "BootstrapActions" not in jf
+    assert jf["BootstrapActions"] == []
     esd = jf["ExecutionStatusDetail"]
     assert isinstance(esd["CreationDateTime"], datetime)
     # assert isinstance(esd['EndDateTime'], 'datetime.datetime')
@@ -342,9 +393,8 @@ def test_list_clusters():
     # the nearest second internally
     time.sleep(1)
     timestamp = datetime.now(timezone.utc)
-    time.sleep(1)
 
-    for idx in range(40, 70):
+    for idx in range(40, 55):
         cluster_name = "jobflow" + str(idx)
         args["Name"] = cluster_name
         cluster_id = client.run_job_flow(**args)["JobFlowId"]
@@ -379,7 +429,7 @@ def test_list_clusters():
         args = {"Marker": marker}
 
     resp = client.list_clusters(ClusterStates=["TERMINATED"])
-    assert len(resp["Clusters"]) == 30
+    assert len(resp["Clusters"]) == 15
     for x in resp["Clusters"]:
         assert x["Status"]["State"] == "TERMINATED"
 
@@ -387,7 +437,7 @@ def test_list_clusters():
     assert len(resp["Clusters"]) == 40
 
     resp = client.list_clusters(CreatedAfter=timestamp)
-    assert len(resp["Clusters"]) == 30
+    assert len(resp["Clusters"]) == 15
 
 
 @mock_aws
@@ -481,7 +531,7 @@ def _do_assertion_ebs_configuration(x, y):
 
 @mock_aws
 def test_run_job_flow_with_instance_groups():
-    input_groups = dict((g["Name"], g) for g in input_instance_groups)
+    input_groups = {g["Name"]: g for g in input_instance_groups}
     client = boto3.client("emr", region_name="us-east-1")
     args = deepcopy(run_job_flow_args)
     args["Instances"] = {"InstanceGroups": input_instance_groups}
@@ -534,7 +584,7 @@ auto_scaling_policy = {
 
 @mock_aws
 def test_run_job_flow_with_instance_groups_with_autoscaling():
-    input_groups = dict((g["Name"], g) for g in input_instance_groups)
+    input_groups = {g["Name"]: g for g in input_instance_groups}
 
     input_groups["core"]["AutoScalingPolicy"] = auto_scaling_policy
     input_groups["task-1"]["AutoScalingPolicy"] = auto_scaling_policy
@@ -737,7 +787,7 @@ def test_set_visible_to_all_users():
     assert resp["Cluster"]["VisibleToAllUsers"] is False
 
     for expected in (True, False):
-        resp = client.set_visible_to_all_users(
+        client.set_visible_to_all_users(
             JobFlowIds=[cluster_id], VisibleToAllUsers=expected
         )
         resp = client.describe_cluster(ClusterId=cluster_id)
@@ -796,7 +846,7 @@ def test_bootstrap_actions():
 
 @mock_aws
 def test_instances():
-    input_groups = dict((g["Name"], g) for g in input_instance_groups)
+    input_groups = {g["Name"]: g for g in input_instance_groups}
     client = boto3.client("emr", region_name="us-east-1")
     args = deepcopy(run_job_flow_args)
     args["Instances"] = {"InstanceGroups": input_instance_groups}
@@ -837,7 +887,7 @@ def test_instances():
 
 @mock_aws
 def test_instance_groups():
-    input_groups = dict((g["Name"], g) for g in input_instance_groups)
+    input_groups = {g["Name"]: g for g in input_instance_groups}
 
     client = boto3.client("emr", region_name="us-east-1")
     args = deepcopy(run_job_flow_args)
@@ -912,7 +962,7 @@ def test_instance_groups():
         # assert isinstance(x['Status']['Timeline']['EndDateTime'], 'datetime.datetime')
         assert isinstance(x["Status"]["Timeline"]["ReadyDateTime"], datetime)
 
-    igs = dict((g["Name"], g) for g in groups)
+    igs = {g["Name"]: g for g in groups}
     client.modify_instance_groups(
         InstanceGroups=[
             {"InstanceGroupId": igs["task-1"]["Id"], "InstanceCount": 2},
@@ -921,7 +971,7 @@ def test_instance_groups():
     )
     jf = client.describe_job_flows(JobFlowIds=[cluster_id])["JobFlows"][0]
     assert jf["Instances"]["InstanceCount"] == base_instance_count + 5
-    igs = dict((g["Name"], g) for g in jf["Instances"]["InstanceGroups"])
+    igs = {g["Name"]: g for g in jf["Instances"]["InstanceGroups"]}
     assert igs["task-1"]["InstanceRunningCount"] == 2
     assert igs["task-2"]["InstanceRunningCount"] == 3
 
@@ -1013,7 +1063,7 @@ def test_steps():
             )
         assert x["StepConfig"]["Name"] == y["Name"]
 
-    expected = dict((s["Name"], s) for s in input_steps)
+    expected = {s["Name"]: s for s in input_steps}
 
     steps = client.list_steps(ClusterId=cluster_id)["Steps"]
     assert len(steps) == 2
@@ -1125,19 +1175,21 @@ def test_security_configurations():
 
     with pytest.raises(ClientError) as ex:
         client.describe_security_configuration(Name=security_configuration_name)
-    err = ex.value.response["Error"]
-    assert err["Code"] == "InvalidRequestException"
+    resp = ex.value.response
+    assert resp["Error"]["Code"] == "InvalidRequestException"
+    assert resp["ErrorCode"] == "ResourceNotFound"
     assert (
-        err["Message"]
+        resp["Error"]["Message"]
         == "Security configuration with name 'MySecurityConfiguration' does not exist."
     )
 
     with pytest.raises(ClientError) as ex:
         client.delete_security_configuration(Name=security_configuration_name)
-    err = ex.value.response["Error"]
-    assert err["Code"] == "InvalidRequestException"
+    resp = ex.value.response
+    assert resp["Error"]["Code"] == "InvalidRequestException"
+    assert resp["ErrorCode"] == "ResourceNotFound"
     assert (
-        err["Message"]
+        resp["Error"]["Message"]
         == "Security configuration with name 'MySecurityConfiguration' does not exist."
     )
 
@@ -1145,9 +1197,9 @@ def test_security_configurations():
 @mock_aws
 def test_run_job_flow_with_invalid_number_of_master_nodes_raises_error():
     client = boto3.client("emr", region_name="us-east-1")
-    params = dict(
-        Name="test-cluster",
-        Instances={
+    params = {
+        "Name": "test-cluster",
+        "Instances": {
             "InstanceGroups": [
                 {
                     "InstanceCount": 2,
@@ -1158,7 +1210,7 @@ def test_run_job_flow_with_invalid_number_of_master_nodes_raises_error():
                 }
             ]
         },
-    )
+    }
     with pytest.raises(ClientError) as ex:
         client.run_job_flow(**params)
     error = ex.value.response["Error"]
@@ -1172,9 +1224,9 @@ def test_run_job_flow_with_invalid_number_of_master_nodes_raises_error():
 @mock_aws
 def test_run_job_flow_with_multiple_master_nodes():
     client = boto3.client("emr", region_name="us-east-1")
-    params = dict(
-        Name="test-cluster",
-        Instances={
+    params = {
+        "Name": "test-cluster",
+        "Instances": {
             "InstanceGroups": [
                 {
                     "InstanceCount": 3,
@@ -1187,7 +1239,7 @@ def test_run_job_flow_with_multiple_master_nodes():
             "KeepJobFlowAliveWhenNoSteps": False,
             "TerminationProtected": False,
         },
-    )
+    }
     cluster_id = client.run_job_flow(**params)["JobFlowId"]
     cluster = client.describe_cluster(ClusterId=cluster_id)["Cluster"]
     assert cluster["AutoTerminate"] is False
