@@ -705,7 +705,7 @@ def test_put_events():
         with warnings.catch_warnings(record=True) as ws:
             client.put_events(Entries=[event])
         messages = [str(w.message) for w in ws]
-        assert any(["EventDetail should be of type dict" in msg for msg in messages])
+        assert any("EventDetail should be of type dict" in msg for msg in messages)
 
 
 @mock_aws
@@ -853,25 +853,35 @@ def test_describe_event_bus():
     client = boto3.client("events", "us-east-1")
 
     response = client.describe_event_bus()
-
     assert response["Name"] == "default"
     assert response["Arn"] == f"arn:aws:events:us-east-1:{ACCOUNT_ID}:event-bus/default"
     assert "Policy" not in response
+    assert "CreationTime" in response
+    assert "LastModifiedTime" in response
+
+    bus_name = "test-bus"
+    client.create_event_bus(
+        Name=bus_name,
+        Description="Test description",
+        KmsKeyIdentifier="arn:aws:kms:us-east-1:123456789012:key/test",
+        DeadLetterConfig={"Arn": "arn:aws:sqs:us-east-1:123456789012:dlq"},
+    )
 
-    client.create_event_bus(Name="test-bus")
     client.put_permission(
-        EventBusName="test-bus",
+        EventBusName=bus_name,
         Action="events:PutEvents",
         Principal="111111111111",
         StatementId="test",
     )
 
-    response = client.describe_event_bus(Name="test-bus")
+    response = client.describe_event_bus(Name=bus_name)
 
-    assert response["Name"] == "test-bus"
+    assert response["Name"] == bus_name
     assert (
-        response["Arn"] == f"arn:aws:events:us-east-1:{ACCOUNT_ID}:event-bus/test-bus"
+        response["Arn"] == f"arn:aws:events:us-east-1:{ACCOUNT_ID}:event-bus/{bus_name}"
     )
+    assert "CreationTime" in response
+    assert "LastModifiedTime" in response
     assert json.loads(response["Policy"]) == {
         "Version": "2012-10-17",
         "Statement": [
@@ -880,11 +890,17 @@ def test_describe_event_bus():
                 "Effect": "Allow",
                 "Principal": {"AWS": "arn:aws:iam::111111111111:root"},
                 "Action": "events:PutEvents",
-                "Resource": f"arn:aws:events:us-east-1:{ACCOUNT_ID}:event-bus/test-bus",
+                "Resource": f"arn:aws:events:us-east-1:{ACCOUNT_ID}:event-bus/{bus_name}",
             }
         ],
     }
 
+    assert response["Description"] == "Test description"
+    assert response["KmsKeyIdentifier"] == "arn:aws:kms:us-east-1:123456789012:key/test"
+    assert response["DeadLetterConfig"] == {
+        "Arn": "arn:aws:sqs:us-east-1:123456789012:dlq"
+    }
+
 
 @mock_aws
 def test_describe_event_bus_errors():
@@ -2289,6 +2305,49 @@ def test_start_replay_send_to_log_group():
     assert event_replay["replay-name"] == "test-replay"
 
 
+@mock_aws
+def test_send_transformed_events_to_log_group():
+    # given
+    client = boto3.client("events", "eu-central-1")
+    logs_client = boto3.client("logs", "eu-central-1")
+    log_group_name = "/test-group"
+    rule_name = "test-rule"
+    logs_client.create_log_group(logGroupName=log_group_name)
+
+    client.put_rule(Name=rule_name, EventPattern=json.dumps({"account": [ACCOUNT_ID]}))
+    client.put_targets(
+        Rule=rule_name,
+        Targets=[
+            {
+                "Id": "test",
+                "Arn": f"arn:aws:logs:eu-central-1:{ACCOUNT_ID}:log-group:{log_group_name}",
+                "InputTransformer": {
+                    # TODO: validate whether is this a valid template for AWS, or if certain fields are required
+                    "InputTemplate": '{"id": "test"}'
+                },
+            }
+        ],
+    )
+
+    # when
+    client.put_events(
+        Entries=[
+            {
+                "Time": datetime.now(),
+                "Source": "source",
+                "DetailType": "type",
+                "Detail": json.dumps({"key": "value"}),
+            }
+        ]
+    )
+
+    # then
+    log_events = logs_client.filter_log_events(logGroupName=log_group_name)["events"]
+    assert len(log_events) == 1
+    event_original = json.loads(log_events[0]["message"])
+    assert event_original == {"id": "test"}
+
+
 @mock_aws
 def test_create_and_list_connections():
     client = boto3.client("events", "eu-central-1")
@@ -2418,6 +2477,7 @@ def test_kms_key_is_created(auth_type, auth_parameters, with_headers):
         assert secret["Tags"] == [
             {"Key": "aws:secretsmanager:owningService", "Value": "events"}
         ]
+        assert secret["OwningService"] == "events"
 
         if auth_type == "BASIC":
             expected_secret = {"username": "un", "password": "pw"}
@@ -2439,18 +2499,19 @@ def test_kms_key_is_created(auth_type, auth_parameters, with_headers):
 
         secret_deleted = False
         attempts = 0
-        while not secret_deleted and attempts < 5:
+        while not secret_deleted and attempts < 10:
             try:
                 attempts += 1
                 secrets.describe_secret(SecretId=secret_arn)
                 sleep(1)
-            except ClientError as e:
-                secret_deleted = (
-                    e.response["Error"]["Code"] == "ResourceNotFoundException"
-                )
+            except ClientError as exc:
+                err = exc.response["Error"]
+                secret_deleted = err["Code"] == "ResourceNotFoundException"
 
         if not secret_deleted:
-            assert False, f"Should have automatically deleted secret {secret_arn}"
+            raise AssertionError(
+                f"Should have automatically deleted secret {secret_arn}"
+            )
     finally:
         if not connection_deleted:
             client.delete_connection(Name=name)
@@ -2572,7 +2633,7 @@ def test_create_and_update_api_destination(key, initial_value, updated_value):
     destination = client.describe_api_destination(Name="test")
     assert destination[key] == initial_value
 
-    client.update_api_destination(Name="test", **dict({key: updated_value}))
+    client.update_api_destination(Name="test", **{key: updated_value})
 
     destination = client.describe_api_destination(Name="test")
     assert destination[key] == updated_value
