@@ -1109,7 +1109,7 @@ def test_batch_delete_partition_with_bad_partitions():
     )
 
     assert len(response["Errors"]) == 3
-    error_partitions = map(lambda x: x["PartitionValues"], response["Errors"])
+    error_partitions = (x["PartitionValues"] for x in response["Errors"])
     assert ["2018-11-01"] in error_partitions
     assert ["2018-11-02"] in error_partitions
     assert ["2018-11-03"] in error_partitions
@@ -1324,6 +1324,7 @@ def test_get_crawlers_several_items():
 def test_start_crawler():
     client = boto3.client("glue", region_name="us-east-1")
     name = "my_crawler_name"
+
     helpers.create_crawler(client, name)
 
     client.start_crawler(Name=name)
@@ -1338,6 +1339,7 @@ def test_start_crawler():
 def test_start_crawler_should_raise_exception_if_already_running():
     client = boto3.client("glue", region_name="us-east-1")
     name = "my_crawler_name"
+
     helpers.create_crawler(client, name)
 
     client.start_crawler(Name=name)
@@ -1351,7 +1353,9 @@ def test_start_crawler_should_raise_exception_if_already_running():
 def test_stop_crawler():
     client = boto3.client("glue", region_name="us-east-1")
     name = "my_crawler_name"
+
     helpers.create_crawler(client, name)
+
     client.start_crawler(Name=name)
 
     client.stop_crawler(Name=name)
@@ -1405,3 +1409,327 @@ def test_delete_crawler_not_exists():
     assert (
         exc.value.response["Error"]["Message"] == "Crawler my_crawler_name not found."
     )
+
+
+@mock_aws
+def test_list_crawls():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    client.start_crawler(Name=name)
+
+    response = client.list_crawls(CrawlerName=name)
+    assert len(response["Crawls"]) == 1
+
+
+@mock_aws
+def test_list_crawls_no_crawler_with_name():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "non_existent_crawler"
+
+    with pytest.raises(ClientError) as exc:
+        client.list_crawls(CrawlerName=name)
+
+    assert exc.value.response["Error"]["Code"] == "EntityNotFoundException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == f"Crawler entry with name {name} does not exist"
+    )
+
+
+@mock_aws
+def test_bad_filter_operator():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    bad_filter_value = "bad_value"
+
+    with pytest.raises(ClientError) as exc:
+        client.list_crawls(
+            CrawlerName=name,
+            Filters=[
+                {
+                    "FieldName": "CRAWL_ID",
+                    "FilterOperator": bad_filter_value,
+                    "FieldValue": "ee3401e1-b7b9-4d76-adfc-202e5484b8e1",
+                }
+            ],
+        )
+
+    assert exc.value.response["Error"]["Code"] == "ValidationException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == f"Value '{bad_filter_value}' at 'filters.1.member.filterOperator' failed to satisfy constraint: Member must satisfy enum value set: [LT, EQ, GT, NE, LE, GE]"
+    )
+
+
+@mock_aws
+def test_bad_filter_field_name():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    bad_field_name = "bad_value"
+
+    with pytest.raises(ClientError) as exc:
+        client.list_crawls(
+            CrawlerName=name,
+            Filters=[
+                {
+                    "FieldName": bad_field_name,
+                    "FilterOperator": "LE",
+                    "FieldValue": "ee3401e1-b7b9-4d76-adfc-202e5484b8e1",
+                }
+            ],
+        )
+
+    assert exc.value.response["Error"]["Code"] == "ValidationException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == f"Value '{bad_field_name}' at 'filters.1.member.fieldName' failed to satisfy constraint: Member must satisfy enum value set: [START_TIME, END_TIME, STATE, CRAWL_ID, DPU_HOUR]"
+    )
+
+
+@mock_aws
+def test_use_ordered_compare_operator_on_state_field():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    with pytest.raises(ClientError) as exc:
+        client.list_crawls(
+            CrawlerName=name,
+            Filters=[
+                {
+                    "FieldName": "STATE",
+                    "FilterOperator": "LE",
+                    "FieldValue": "RUNNING",
+                }
+            ],
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == "Only EQ or NE operator is allowed for field : STATE"
+    )
+
+
+@mock_aws
+def test_use_ordered_compare_operator_on_uid_field():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    with pytest.raises(ClientError) as exc:
+        client.list_crawls(
+            CrawlerName=name,
+            Filters=[
+                {
+                    "FieldName": "CRAWL_ID",
+                    "FilterOperator": "LE",
+                    "FieldValue": "some_uid",
+                }
+            ],
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == "Only EQ or NE operator is allowed for field : CRAWL_ID"
+    )
+
+
+@mock_aws
+@pytest.mark.parametrize("operator", ["NE", "EQ"])
+def test_filter_crawls_for_state(operator):
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    client.start_crawler(Name=name)
+    # turn crawler to completed
+    client.list_crawls(CrawlerName=name)
+    client.start_crawler(Name=name)
+
+    crawls = client.list_crawls(
+        CrawlerName=name,
+        Filters=[
+            {
+                "FieldName": "STATE",
+                "FilterOperator": operator,
+                "FieldValue": "RUNNING",
+            }
+        ],
+    )
+
+    assert len(crawls["Crawls"]) == 1
+
+
+@mock_aws
+@pytest.mark.parametrize("operator", ["LE", "LT", "GE", "GT"])
+def test_filter_crawls_for_start_time(operator):
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    client.start_crawler(Name=name)
+    between_the_two_run_starts = datetime.now()
+    # turn crawler to completed
+    client.list_crawls(CrawlerName=name)
+
+    client.start_crawler(Name=name)
+
+    crawls = client.list_crawls(
+        CrawlerName=name,
+        Filters=[
+            {
+                "FieldName": "START_TIME",
+                "FilterOperator": operator,
+                "FieldValue": between_the_two_run_starts.isoformat(),
+            }
+        ],
+    )
+
+    assert len(crawls["Crawls"]) == 1
+
+
+@mock_aws
+@pytest.mark.parametrize("operator", ["LE", "LT", "GE", "GT"])
+def test_filter_crawls_for_end_time(operator):
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    client.start_crawler(Name=name)
+    # turn crawler to completed
+    client.list_crawls(CrawlerName=name)
+
+    client.start_crawler(Name=name)
+    between_the_two_run_ends = datetime.now()
+    client.list_crawls(CrawlerName=name)
+
+    crawls = client.list_crawls(
+        CrawlerName=name,
+        Filters=[
+            {
+                "FieldName": "END_TIME",
+                "FilterOperator": operator,
+                "FieldValue": between_the_two_run_ends.isoformat(),
+            }
+        ],
+    )
+
+    assert len(crawls["Crawls"]) == 1
+
+
+@mock_aws
+@pytest.mark.parametrize("operator", ["LE", "LT", "GE", "GT"])
+def test_multiple_filters(operator):
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    client.start_crawler(Name=name)
+    # turn crawler to completed
+    client.list_crawls(CrawlerName=name)
+
+    between_the_two_runs = datetime.now()
+    client.start_crawler(Name=name)
+    client.list_crawls(CrawlerName=name)
+
+    crawls = client.list_crawls(
+        CrawlerName=name,
+        Filters=[
+            {
+                "FieldName": "END_TIME",
+                "FilterOperator": operator,
+                "FieldValue": between_the_two_runs.isoformat(),
+            },
+            {
+                "FieldName": "START_TIME",
+                "FilterOperator": operator,
+                "FieldValue": between_the_two_runs.isoformat(),
+            },
+        ],
+    )
+
+    assert len(crawls["Crawls"]) == 1
+
+
+@mock_aws
+def test_filter_crawls_for_crawl_id():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    client.start_crawler(Name=name)
+
+    first_crawl_crawl_id = client.list_crawls(CrawlerName=name)["Crawls"][0]["CrawlId"]
+    client.start_crawler(Name=name)
+
+    crawls = client.list_crawls(
+        CrawlerName=name,
+        Filters=[
+            {
+                "FieldName": "CRAWL_ID",
+                "FilterOperator": "EQ",
+                "FieldValue": first_crawl_crawl_id,
+            }
+        ],
+    )
+
+    assert len(crawls["Crawls"]) == 1
+    assert crawls["Crawls"][0]["CrawlId"] == first_crawl_crawl_id
+
+
+@mock_aws
+def test_filter_crawls_for_not_crawl_id():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    client.start_crawler(Name=name)
+
+    first_crawl_crawl_id = client.list_crawls(CrawlerName=name)["Crawls"][0]["CrawlId"]
+    client.start_crawler(Name=name)
+
+    crawls = client.list_crawls(
+        CrawlerName=name,
+        Filters=[
+            {
+                "FieldName": "CRAWL_ID",
+                "FilterOperator": "NE",
+                "FieldValue": first_crawl_crawl_id,
+            }
+        ],
+    )
+
+    assert len(crawls["Crawls"]) == 1
+    assert crawls["Crawls"][0]["CrawlId"] != first_crawl_crawl_id
+
+
+@mock_aws
+def test_crawl_filter_missing_field():
+    client = boto3.client("glue", region_name="us-east-1")
+    name = "my_crawler_name"
+    helpers.create_crawler(client, name)
+
+    with pytest.raises(ClientError) as exc:
+        client.list_crawls(
+            CrawlerName=name,
+            Filters=[
+                {
+                    "FieldName": "CRAWL_ID",
+                    "FilterOperator": "NE",
+                }
+            ],
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == "Invalid Filter Provided: FieldName: CRAWL_ID, FilterOperator: NE, FieldValue: null"
+    )
