@@ -55,6 +55,28 @@ def test_create_db_cluster__with_additional_params():
     assert resp["DatabaseName"] == "sth"
 
 
+@mock_aws
+def test_create_db_cluster_with_instance():
+    client = boto3.client("neptune", region_name="us-east-2")
+    resp = client.create_db_cluster(DBClusterIdentifier="cluster-id", Engine="neptune")[
+        "DBCluster"
+    ]
+    client.create_db_instance(
+        DBInstanceIdentifier="instance-id",
+        DBClusterIdentifier="cluster-id",
+        Engine="neptune",
+        DBInstanceClass="db.r5.large",
+    )
+    resp = client.describe_db_instances(DBInstanceIdentifier="instance-id")[
+        "DBInstances"
+    ]
+    assert resp[0]["DBInstanceIdentifier"] == "instance-id"
+    assert resp[0]["DBInstanceClass"] == "db.r5.large"
+    assert resp[0]["DBClusterIdentifier"] == "cluster-id"
+    assert resp[0]["Engine"] == "neptune"
+    assert resp[0]["EngineVersion"] == "1.3.2.1"
+
+
 @mock_aws
 def test_describe_db_clusters():
     client = boto3.client("neptune", region_name="ap-southeast-1")
@@ -80,6 +102,33 @@ def test_delete_db_cluster():
     assert client.describe_db_clusters()["DBClusters"] == []
 
 
+@mock_aws
+def test_remove_db_instance():
+    client = boto3.client("neptune", region_name="us-east-2")
+    client.create_db_cluster(DBClusterIdentifier="cluster-id", Engine="neptune")[
+        "DBCluster"
+    ]
+    client.create_db_instance(
+        DBInstanceIdentifier="instance-id",
+        DBClusterIdentifier="cluster-id",
+        Engine="neptune",
+        DBInstanceClass="db.r5.large",
+    )
+
+    cluster = client.describe_db_clusters()["DBClusters"][0]
+    assert "DBClusterMembers" in cluster
+    assert len(cluster["DBClusterMembers"]) == 1
+
+    client.delete_db_instance(
+        DBInstanceIdentifier="instance-id",
+        SkipFinalSnapshot=True,
+    )
+
+    cluster = client.describe_db_clusters()["DBClusters"][0]
+    assert "DBClusterMembers" in cluster
+    assert len(cluster["DBClusterMembers"]) == 0
+
+
 @mock_aws
 def test_delete_unknown_db_cluster():
     client = boto3.client("neptune", region_name="ap-southeast-1")
