@@ -5,14 +5,13 @@ import pytest
 from botocore.exceptions import ClientError
 
 from moto import mock_aws
+from moto.s3.responses import DEFAULT_REGION_NAME
 
 
 @mock_aws
 def test_lifecycle_with_filters():
-    client = boto3.client("s3")
-    client.create_bucket(
-        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
-    )
+    client = boto3.client("s3", DEFAULT_REGION_NAME)
+    client.create_bucket(Bucket="bucket")
 
     # Create a lifecycle rule with a Filter (no tags):
     lfc = {
@@ -223,10 +222,8 @@ def test_lifecycle_with_filters():
 
 @mock_aws
 def test_lifecycle_with_eodm():
-    client = boto3.client("s3")
-    client.create_bucket(
-        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
-    )
+    client = boto3.client("s3", DEFAULT_REGION_NAME)
+    client.create_bucket(Bucket="bucket")
 
     lfc = {
         "Rules": [
@@ -273,10 +270,8 @@ def test_lifecycle_with_eodm():
 
 @mock_aws
 def test_lifecycle_with_nve():
-    client = boto3.client("s3")
-    client.create_bucket(
-        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
-    )
+    client = boto3.client("s3", DEFAULT_REGION_NAME)
+    client.create_bucket(Bucket="bucket")
 
     lfc = {
         "Rules": [
@@ -309,10 +304,8 @@ def test_lifecycle_with_nve():
 
 @mock_aws
 def test_lifecycle_with_nvt():
-    client = boto3.client("s3")
-    client.create_bucket(
-        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
-    )
+    client = boto3.client("s3", DEFAULT_REGION_NAME)
+    client.create_bucket(Bucket="bucket")
 
     lfc = {
         "Rules": [
@@ -377,10 +370,8 @@ def test_lifecycle_with_nvt():
 
 @mock_aws
 def test_lifecycle_with_multiple_nvt():
-    client = boto3.client("s3")
-    client.create_bucket(
-        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
-    )
+    client = boto3.client("s3", DEFAULT_REGION_NAME)
+    client.create_bucket(Bucket="bucket")
 
     lfc = {
         "Rules": [
@@ -412,10 +403,8 @@ def test_lifecycle_with_multiple_nvt():
 
 @mock_aws
 def test_lifecycle_with_multiple_transitions():
-    client = boto3.client("s3")
-    client.create_bucket(
-        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
-    )
+    client = boto3.client("s3", DEFAULT_REGION_NAME)
+    client.create_bucket(Bucket="bucket")
 
     lfc = {
         "Rules": [
@@ -447,10 +436,8 @@ def test_lifecycle_with_multiple_transitions():
 
 @mock_aws
 def test_lifecycle_with_aimu():
-    client = boto3.client("s3")
-    client.create_bucket(
-        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
-    )
+    client = boto3.client("s3", DEFAULT_REGION_NAME)
+    client.create_bucket(Bucket="bucket")
 
     lfc = {
         "Rules": [
@@ -487,7 +474,7 @@ def test_lifecycle_with_aimu():
 
 
 @mock_aws
-def test_lifecycle_with_glacier_transition_boto3():
+def test_lifecycle_with_glacier_transition():
     s3_resource = boto3.resource("s3", region_name="us-east-1")
     client = boto3.client("s3", region_name="us-east-1")
     s3_resource.create_bucket(Bucket="foobar")
@@ -518,7 +505,7 @@ def test_lifecycle_with_glacier_transition_boto3():
 
 
 @mock_aws
-def test_lifecycle_multi_boto3():
+def test_lifecycle_multi():
     s3_resource = boto3.resource("s3", region_name="us-east-1")
     client = boto3.client("s3", region_name="us-east-1")
     s3_resource.create_bucket(Bucket="foobar")
@@ -586,11 +573,11 @@ def test_lifecycle_multi_boto3():
             )
             assert rule["Transitions"][0]["StorageClass"] == storage_class
         else:
-            assert False, "Invalid rule id"
+            raise AssertionError("Invalid rule id")
 
 
 @mock_aws
-def test_lifecycle_delete_boto3():
+def test_lifecycle_delete():
     s3_resource = boto3.resource("s3", region_name="us-east-1")
     client = boto3.client("s3", region_name="us-east-1")
     s3_resource.create_bucket(Bucket="foobar")
@@ -610,3 +597,36 @@ def test_lifecycle_delete_boto3():
     assert ex.value.response["Error"]["Message"] == (
         "The lifecycle configuration does not exist"
     )
+
+
+@mock_aws
+def test_lifecycle_empty_configuration():
+    """Test that empty lifecycle configuration (no rules) works correctly"""
+    client = boto3.client("s3", DEFAULT_REGION_NAME)
+    client.create_bucket(Bucket="foobar")
+
+    # Set lifecycle configuration with rules first
+    client.put_bucket_lifecycle_configuration(
+        Bucket="foobar",
+        LifecycleConfiguration={
+            "Rules": [{"ID": "myid", "Prefix": "", "Status": "Enabled"}]
+        },
+    )
+
+    # Verify it exists
+    result = client.get_bucket_lifecycle_configuration(Bucket="foobar")
+    assert len(result["Rules"]) == 1
+
+    # Set empty lifecycle configuration (should delete all rules)
+    client.put_bucket_lifecycle_configuration(
+        Bucket="foobar",
+        LifecycleConfiguration={"Rules": []},
+    )
+
+    # Verify it's deleted
+    with pytest.raises(ClientError) as ex:
+        client.get_bucket_lifecycle_configuration(Bucket="foobar")
+    assert ex.value.response["Error"]["Code"] == "NoSuchLifecycleConfiguration"
+    assert ex.value.response["Error"]["Message"] == (
+        "The lifecycle configuration does not exist"
+    )
