@@ -14,6 +14,7 @@ from freezegun import freeze_time
 
 from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from moto.secretsmanager.models import secretsmanager_backends
 from moto.secretsmanager.utils import SecretsManagerSecretIdentifier
 from moto.utilities.id_generator import TAG_KEY_CUSTOM_ID
 from tests import allow_aws_request
@@ -762,8 +763,10 @@ def test_get_random_too_short_password():
 def test_get_random_too_long_password():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
 
-    with pytest.raises(Exception):
+    with pytest.raises(ClientError) as exc:
         conn.get_random_password(PasswordLength=5555)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidParameterValue"
 
 
 @mock_aws
@@ -1183,7 +1186,7 @@ def lambda_handler(event, context):
     except Exception as e:
         pending_value = str(e)
     print(pending_value)
-    
+
     dynamodb = boto3.resource("dynamodb", region_name="us-east-1", """
         + endpoint
         + """)
@@ -1313,6 +1316,9 @@ def test_rotate_secret_using_lambda(secret=None, iam_role_arn=None, table_name=N
             sleep(5)
     rotated_version = updated_secret["VersionId"]
 
+    # Delete function as early as possible, to ensure it's not left dangling
+    lambda_conn.delete_function(FunctionName=function_name)
+
     assert initial_version != rotated_version
 
     u2 = secrets_conn.get_secret_value(SecretId=secret["ARN"])
@@ -1321,11 +1327,10 @@ def test_rotate_secret_using_lambda(secret=None, iam_role_arn=None, table_name=N
 
     metadata = secrets_conn.describe_secret(SecretId=secret["ARN"])
     assert metadata["VersionIdsToStages"][initial_version] == ["AWSPREVIOUS"]
-    assert metadata["VersionIdsToStages"][rotated_version] == ["AWSCURRENT"]
+    # XXX: Test is non-deterministic - sometimes this will return AWSCURRENT, sometimes both AWSCURRENT and AWSPENDING
+    assert "AWSCURRENT" in metadata["VersionIdsToStages"][rotated_version]
     assert updated_secret["SecretString"] == "UpdatedValue"
 
-    lambda_conn.delete_function(FunctionName=function_name)
-
     dynamodb = boto3.resource("dynamodb", region_name="us-east-1")
     items = dynamodb.Table(table_name).scan()["Items"]
 
@@ -1547,6 +1552,19 @@ def test_put_secret_value_versions_differ_if_same_secret_put_twice():
     assert first_version_id != second_version_id
 
 
+@mock_aws
+def test_put_secret_value_versions_adds_awscurrent_label_in_first_version():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+    conn.create_secret(Name=DEFAULT_SECRET_NAME)
+    put_secret_value_dict = conn.put_secret_value(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString="dupe_secret",
+        VersionStages=["AWSPENDING"],
+    )
+
+    assert put_secret_value_dict["VersionStages"] == ["AWSPENDING", "AWSCURRENT"]
+
+
 @mock_aws
 def test_put_secret_value_maintains_description_and_tags():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -1604,6 +1622,85 @@ def test_can_list_secret_version_ids():
     assert [first_version_id, second_version_id].sort() == returned_version_ids.sort()
 
 
+@mock_aws
+def test_managing_secrets_versions_with_client_request_tokens():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+    # Create a secret with a specific client request token
+    crt = uuid4()
+    response = conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString="first_secret_string",
+        ClientRequestToken=str(crt),
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+    assert response["VersionId"] == str(crt)
+    secret_arn = response["ARN"]
+    # Trying to create this secret again with the same ClientRequestToken AND the same secret value should
+    # result in the request just being ignored
+    response = conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString="first_secret_string",
+        ClientRequestToken=str(crt),
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+    assert response["VersionId"] == str(crt)
+    # However, trying to use the same ClientRequestToken but modifying the secret string value should result
+    # in a ResourceExistsException
+    with pytest.raises(ClientError) as exc:
+        conn.create_secret(
+            Name=DEFAULT_SECRET_NAME,
+            SecretString="first_secret_string-new",
+            ClientRequestToken=str(crt),
+        )
+    assert exc.value.response["Error"]["Code"] == "ResourceExistsException"
+    assert exc.value.response["Error"]["Message"] == (
+        f"You can't use ClientRequestToken {str(crt)} because that value is already in use for a version of secret {secret_arn}"
+    )
+
+    # The same applies when using PutSecret as well
+    # Trying to use the same ClientRequestToken AND the same secret value should result in the request just being ignored
+    response = conn.put_secret_value(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString="first_secret_string",
+        ClientRequestToken=str(crt),
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+    assert response["VersionId"] == str(crt)
+    # However, trying to use the same ClientRequestToken but modifying the secret string value should result
+    # in a ResourceExistsException
+    with pytest.raises(ClientError) as exc:
+        conn.put_secret_value(
+            SecretId=DEFAULT_SECRET_NAME,
+            SecretString="first_secret_string-new",
+            ClientRequestToken=str(crt),
+        )
+    assert exc.value.response["Error"]["Code"] == "ResourceExistsException"
+    assert exc.value.response["Error"]["Message"] == (
+        f"You can't use ClientRequestToken {str(crt)} because that value is already in use for a version of secret {secret_arn}"
+    )
+
+    # And finally, we repeat the set of steps with UpdateSecret
+    response = conn.update_secret(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString="first_secret_string",
+        ClientRequestToken=str(crt),
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+    assert response["VersionId"] == str(crt)
+    # However, trying to use the same ClientRequestToken but modifying the secret string value should result
+    # in a ResourceExistsException
+    with pytest.raises(ClientError) as exc:
+        conn.update_secret(
+            SecretId=DEFAULT_SECRET_NAME,
+            SecretString="first_secret_string-new",
+            ClientRequestToken=str(crt),
+        )
+    assert exc.value.response["Error"]["Code"] == "ResourceExistsException"
+    assert exc.value.response["Error"]["Message"] == (
+        f"You can't use ClientRequestToken {str(crt)} because that value is already in use for a version of secret {secret_arn}"
+    )
+
+
 @mock_aws
 def test_put_secret_value_version_stages_response():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -2105,7 +2202,7 @@ def test_update_secret_version_stage_manually(secret=None):
     current_secret = sm_client.get_secret_value(
         SecretId=secret["ARN"], VersionStage="AWSCURRENT"
     )
-    assert list(sorted(current_secret["VersionStages"])) == ["AWSCURRENT", "AWSPENDING"]
+    assert sorted(current_secret["VersionStages"]) == ["AWSCURRENT", "AWSPENDING"]
     assert current_secret["SecretString"] == "new_secret"
 
     previous_secret = sm_client.get_secret_value(
@@ -2180,3 +2277,30 @@ def test_create_secret_with_tag_custom_id(set_custom_id):
     )
 
     assert secret["ARN"].split(":")[-1] == f"{secret_name}-{secret_suffix}"
+
+
+@mock_aws
+@pytest.mark.skipif(
+    not settings.TEST_DECORATOR_MODE,
+    reason="Can't modify backend directly if not in decorator mode.",
+)
+def test_aws_managed_secret(set_custom_id):
+    # We have to poke directly at the backend because technically this secret
+    # would be managed by RDS, and wouldn't be able to be created via the
+    # public API (due to the restricted 'aws' tag prefix).
+    backend = secretsmanager_backends[DEFAULT_ACCOUNT_ID]["us-east-1"]
+    secret = backend.create_managed_secret("rds", "secret-managed-by-rds", "53cr3t")
+    assert secret.kms_key_id == "alias/aws/secretsmanager"
+    client = boto3.client("secretsmanager", region_name="us-east-1")
+    resp = client.describe_secret(SecretId=secret.arn)
+    assert "KmsKeyId" not in resp
+    assert resp["OwningService"] == "rds"
+    owning_service_filter = {"Key": "owning-service", "Values": ["rds"]}
+    resp = client.list_secrets(Filters=[owning_service_filter])
+    assert len(resp["SecretList"]) == 1
+    assert resp["SecretList"][0]["ARN"] == secret.arn
+    assert resp["SecretList"][0]["OwningService"] == secret.owning_service
+    resp = client.batch_get_secret_value(Filters=[owning_service_filter])
+    assert len(resp["SecretValues"]) == 1
+    assert resp["SecretValues"][0]["ARN"] == secret.arn
+    assert resp["SecretValues"][0]["SecretString"] == "53cr3t"
