@@ -1,3 +1,5 @@
+import json
+
 import boto3
 import pytest
 from botocore.exceptions import ClientError
@@ -6,7 +8,7 @@ from moto import mock_aws, settings
 from moto.ses.models import Message, RawMessage, ses_backends
 from tests import DEFAULT_ACCOUNT_ID
 
-from ..test_ses.test_ses_boto3 import get_raw_email
+from ..test_ses.test_ses import get_raw_email
 
 
 @pytest.fixture(scope="function")
@@ -17,30 +19,30 @@ def ses_v1():
 
 
 @mock_aws
-def test_send_email(ses_v1):  # pylint: disable=redefined-outer-name
+def test_send_email(ses_v1):
     # Setup
     conn = boto3.client("sesv2", region_name="us-east-1")
-    kwargs = dict(
-        FromEmailAddress="test@example.com",
-        Destination={
+    kwargs = {
+        "FromEmailAddress": "test@example.com",
+        "Destination": {
             "ToAddresses": ["test_to@example.com"],
             "CcAddresses": ["test_cc@example.com"],
             "BccAddresses": ["test_bcc@example.com"],
         },
-        Content={
+        "Content": {
             "Simple": {
                 "Subject": {"Data": "test subject"},
                 "Body": {"Text": {"Data": "test body"}},
             },
         },
-    )
+    }
 
     # Execute
     with pytest.raises(ClientError) as e:
         conn.send_email(**kwargs)
     assert e.value.response["Error"]["Code"] == "MessageRejected"
 
-    ses_v1.verify_domain_identity(Domain="example.com")
+    conn.create_email_identity(EmailIdentity="test@example.com")
     resp = conn.send_email(**kwargs)
     assert resp["MessageId"] is not None
 
@@ -58,22 +60,22 @@ def test_send_email(ses_v1):  # pylint: disable=redefined-outer-name
 
 
 @mock_aws
-def test_send_html_email(ses_v1):  # pylint: disable=redefined-outer-name
+def test_send_html_email(ses_v1):
     # Setup
     conn = boto3.client("sesv2", region_name="us-east-1")
-    ses_v1.verify_domain_identity(Domain="example.com")
-    kwargs = dict(
-        FromEmailAddress="test@example.com",
-        Destination={
+    conn.create_email_identity(EmailIdentity="example.com")
+    kwargs = {
+        "FromEmailAddress": "test@example.com",
+        "Destination": {
             "ToAddresses": ["test_to@example.com"],
         },
-        Content={
+        "Content": {
             "Simple": {
                 "Subject": {"Data": "test subject"},
                 "Body": {"Html": {"Data": "<h1>Test HTML</h1>"}},
             },
         },
-    )
+    }
 
     # Execute
     conn.send_email(**kwargs)
@@ -91,18 +93,18 @@ def test_send_html_email(ses_v1):  # pylint: disable=redefined-outer-name
 
 
 @mock_aws
-def test_send_raw_email(ses_v1):  # pylint: disable=redefined-outer-name
+def test_send_raw_email(ses_v1):
     # Setup
     conn = boto3.client("sesv2", region_name="us-east-1")
     message = get_raw_email()
     destination = {
         "ToAddresses": [x.strip() for x in message["To"].split(",")],
     }
-    kwargs = dict(
-        FromEmailAddress=message["From"],
-        Destination=destination,
-        Content={"Raw": {"Data": message.as_bytes()}},
-    )
+    kwargs = {
+        "FromEmailAddress": message["From"],
+        "Destination": destination,
+        "Content": {"Raw": {"Data": message.as_bytes()}},
+    }
 
     # Execute
     ses_v1.verify_email_identity(EmailAddress="test@example.com")
@@ -117,16 +119,16 @@ def test_send_raw_email(ses_v1):  # pylint: disable=redefined-outer-name
 @mock_aws
 def test_send_raw_email__with_specific_message(
     ses_v1,
-):  # pylint: disable=redefined-outer-name
+):
     # Setup
     conn = boto3.client("sesv2", region_name="us-east-1")
     message = get_raw_email()
     # This particular message means that our base64-encoded body contains a '='
     # Testing this to ensure that we parse the body as JSON, not as a query-dict
     message["Subject"] = "Test-2"
-    kwargs = dict(
-        Content={"Raw": {"Data": message.as_bytes()}},
-    )
+    kwargs = {
+        "Content": {"Raw": {"Data": message.as_bytes()}},
+    }
 
     # Execute
     ses_v1.verify_email_identity(EmailAddress="test@example.com")
@@ -148,7 +150,7 @@ def test_send_raw_email__with_specific_message(
 @mock_aws
 def test_send_raw_email__with_to_address_display_name(
     ses_v1,
-):  # pylint: disable=redefined-outer-name
+):
     # Setup
     conn = boto3.client("sesv2", region_name="us-east-1")
     message = get_raw_email()
@@ -156,9 +158,9 @@ def test_send_raw_email__with_to_address_display_name(
     del message["To"]
     display_name = ",".join(["c" for _ in range(50)])
     message["To"] = f""""{display_name}" <to@example.com>, foo@example.com"""
-    kwargs = dict(
-        Content={"Raw": {"Data": message.as_bytes()}},
-    )
+    kwargs = {
+        "Content": {"Raw": {"Data": message.as_bytes()}},
+    }
 
     # Execute
     ses_v1.verify_email_identity(EmailAddress="test@example.com")
@@ -458,6 +460,137 @@ def test_delete_contact():
     assert len(result["Contacts"]) == 0
 
 
+@mock_aws
+def test_create_email_identity():
+    # Setup
+    client = boto3.client("sesv2", region_name="us-east-1")
+    test_email_domain = "example.com"
+
+    # Execute
+    resp = client.create_email_identity(EmailIdentity=test_email_domain)
+
+    # Verify
+    assert resp["IdentityType"] == "DOMAIN"
+    assert resp["VerifiedForSendingStatus"] is False
+
+
+@mock_aws
+def test_delete_email_identity():
+    # Setup
+    client = boto3.client("sesv2", region_name="us-east-1")
+    test_email_domain = "example.com"
+    client.create_email_identity(EmailIdentity=test_email_domain)
+    identities = client.list_email_identities()
+
+    assert len(identities["EmailIdentities"]) == 1
+
+    # Execute
+    client.delete_email_identity(EmailIdentity=test_email_domain)
+
+    # Verify
+    identities = client.list_email_identities()
+    assert len(identities["EmailIdentities"]) == 0
+
+
+@mock_aws
+def test_delete_no_email_identity():
+    # Setup
+    client = boto3.client("sesv2", region_name="us-east-1")
+    test_email_domain = "example.com"
+    identities = client.list_email_identities()
+
+    assert len(identities["EmailIdentities"]) == 0
+
+    # Execute
+    client.delete_email_identity(EmailIdentity=test_email_domain)
+
+    # Verify
+    identities = client.list_email_identities()
+    assert len(identities["EmailIdentities"]) == 0
+
+
+@mock_aws
+def test_get_email_identity():
+    # Setup
+    client = boto3.client("sesv2", region_name="us-east-2")
+    test_email_domain = "example.com"
+    configuration_set_name = "test-config-set"
+    tags = [{"Key": "Owner", "Value": "Zach"}]
+    client.create_email_identity(
+        EmailIdentity=test_email_domain,
+        ConfigurationSetName=configuration_set_name,
+        Tags=tags,
+    )
+
+    # Execute
+    resp = client.get_email_identity(EmailIdentity=test_email_domain)
+
+    # Verify
+    assert resp["IdentityType"] == "DOMAIN"
+    assert resp["ConfigurationSetName"] == configuration_set_name
+    assert resp["Tags"] == tags
+    assert "DkimAttributes" in resp
+    assert resp["DkimAttributes"]["Status"] == "NOT_STARTED"
+    assert not resp["DkimAttributes"]["SigningEnabled"]
+
+
+@mock_aws
+def test_get_email_identity_w_dkim():
+    # Setup
+    client = boto3.client("sesv2", region_name="us-east-2")
+    test_email_domain = "example.com"
+    configuration_set_name = "test-config-set"
+    tags = [{"Key": "Owner", "Value": "Zach"}]
+    dkim_signing_attributes = {
+        "DomainSigningSelector": "test",
+        "DomainSigningPrivateKey": "test",
+        "NextSigningKeyLength": "2048",
+        "DomainSigningAttributesOrigin": "AWS_SES",
+    }
+    client.create_email_identity(
+        EmailIdentity=test_email_domain,
+        ConfigurationSetName=configuration_set_name,
+        Tags=tags,
+        DkimSigningAttributes=dkim_signing_attributes,
+    )
+
+    # Execute
+    resp = client.get_email_identity(EmailIdentity=test_email_domain)
+
+    # Verify
+    assert resp["IdentityType"] == "DOMAIN"
+    assert resp["ConfigurationSetName"] == configuration_set_name
+    assert resp["Tags"] == tags
+    assert "DkimAttributes" in resp
+    assert (
+        resp["DkimAttributes"]["SigningAttributesOrigin"]
+        == dkim_signing_attributes["DomainSigningAttributesOrigin"]
+    )
+    assert resp["DkimAttributes"]["Status"] == "SUCCESS"
+    assert resp["DkimAttributes"]["SigningEnabled"]
+
+
+@mock_aws
+def test_list_email_identities():
+    # Setup
+    client = boto3.client("sesv2", region_name="ap-southeast-1")
+    email_identities = ["example.com", "moto@example.com", "example2.com"]
+    for e in email_identities:
+        client.create_email_identity(EmailIdentity=e)
+
+    # Execute
+    resp = client.list_email_identities()
+
+    # Verify
+    assert len(resp["EmailIdentities"]) == 3
+    for ei in resp["EmailIdentities"]:
+        assert ei["IdentityName"] in email_identities
+        if "@" in ei["IdentityName"]:
+            assert ei["IdentityType"] == "EMAIL_ADDRESS"
+        else:
+            assert ei["IdentityType"] == "DOMAIN"
+
+
 @mock_aws
 def test_create_configuration_set():
     # Setup
@@ -533,7 +666,7 @@ def test_get_configuration_set():
         "GuardianOptions": {"OptimizedSharedDelivery": "DISABLED"},
     }
 
-    client_v1.create_configuration_set(ConfigurationSet=dict({"Name": name_v1}))
+    client_v1.create_configuration_set(ConfigurationSet={"Name": name_v1})
 
     client_v2.create_configuration_set(
         ConfigurationSetName=name_v2,
@@ -558,11 +691,14 @@ def test_get_configuration_set():
     assert config_setv2["Tags"] == tags
     assert config_setv2["DeliveryOptions"] == delivery_options
 
-    # Check for a non-existant config set
+    # Check for a non-existent config set
     with pytest.raises(ClientError) as ex:
         client_v2.get_configuration_set(ConfigurationSetName="invalid")
     err = ex.value.response["Error"]
-    assert err["Code"] == "ConfigurationSetDoesNotExist"
+    assert err["Code"] == "NotFoundException"
+    assert err["Message"] == "Configuration set <invalid> does not exist."
+    resp_meta = ex.value.response["ResponseMetadata"]
+    assert resp_meta["HTTPStatusCode"] == 404
 
 
 @mock_aws
@@ -596,7 +732,7 @@ def test_list_configuration_sets():
         "GuardianOptions": {"OptimizedSharedDelivery": "DISABLED"},
     }
 
-    client_v1.create_configuration_set(ConfigurationSet=dict({"Name": name_v1}))
+    client_v1.create_configuration_set(ConfigurationSet={"Name": name_v1})
 
     client_v2.create_configuration_set(
         ConfigurationSetName=name_v2,
@@ -615,7 +751,7 @@ def test_list_configuration_sets():
     # Validate
     assert len(config_sets["ConfigurationSets"]) == 2
     for c in config_sets["ConfigurationSets"]:
-        assert c in {name_v1, name_v2}
+        assert c in [name_v1, name_v2]
 
 
 @mock_aws
@@ -665,7 +801,10 @@ def test_delete_configuration_set():
     with pytest.raises(ClientError) as ex:
         client.get_configuration_set(ConfigurationSetName=name)
     err = ex.value.response["Error"]
-    assert err["Code"] == "ConfigurationSetDoesNotExist"
+    assert err["Code"] == "NotFoundException"
+    assert err["Message"] == f"Configuration set <{name}> does not exist."
+    resp_meta = ex.value.response["ResponseMetadata"]
+    assert resp_meta["HTTPStatusCode"] == 404
 
 
 @mock_aws
@@ -719,3 +858,169 @@ def test_delete_dedicated_ip_pool():
     with pytest.raises(ClientError) as e:
         client.get_dedicated_ip_pool(PoolName=target_pool_name)
     assert e.value.response["Error"]["Code"] == "NotFoundException"
+
+
+@mock_aws
+def test_create_email_identity_policy():
+    client = boto3.client("sesv2", region_name="us-east-1")
+    email_identity = "example.com"
+    policy_name = "MyPolicy"
+    policy = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": {"AWS": "arn:aws:iam::123456789012:root"},
+                    "Action": ["ses:SendEmail", "ses:SendRawEmail"],
+                    "Resource": f"arn:aws:ses:us-east-1:123456789012:identity/{email_identity}",
+                }
+            ],
+        }
+    )
+
+    client.create_email_identity(EmailIdentity=email_identity)
+
+    response = client.create_email_identity_policy(
+        EmailIdentity=email_identity, PolicyName=policy_name, Policy=policy
+    )
+
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+
+@mock_aws
+def test_delete_email_identity_policy():
+    client = boto3.client("sesv2", region_name="us-east-1")
+    email_identity = "example.com"
+    policy_name = "MyPolicy"
+    policy = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": {"AWS": "arn:aws:iam::123456789012:root"},
+                    "Action": ["ses:SendEmail", "ses:SendRawEmail"],
+                    "Resource": f"arn:aws:ses:us-east-1:123456789012:identity/{email_identity}",
+                }
+            ],
+        }
+    )
+
+    client.create_email_identity(EmailIdentity=email_identity)
+    client.create_email_identity_policy(
+        EmailIdentity=email_identity, PolicyName=policy_name, Policy=policy
+    )
+
+    policies_before = client.get_email_identity_policies(EmailIdentity=email_identity)
+    assert policy_name in policies_before["Policies"]
+
+    response = client.delete_email_identity_policy(
+        EmailIdentity=email_identity, PolicyName=policy_name
+    )
+
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    policies_after = client.get_email_identity_policies(EmailIdentity=email_identity)
+    assert policy_name not in policies_after["Policies"]
+
+    response = client.delete_email_identity_policy(
+        EmailIdentity=email_identity, PolicyName="NonExistentPolicy"
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+
+@mock_aws
+def test_update_email_identity_policy():
+    client = boto3.client("sesv2", region_name="us-east-1")
+    email_identity = "example.com"
+    policy_name = "MyPolicy"
+
+    initial_policy = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": {"AWS": "arn:aws:iam::123456789012:root"},
+                    "Action": ["ses:SendEmail"],
+                    "Resource": f"arn:aws:ses:us-east-1:123456789012:identity/{email_identity}",
+                }
+            ],
+        }
+    )
+
+    updated_policy = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": {"AWS": "arn:aws:iam::123456789012:root"},
+                    "Action": ["ses:SendEmail", "ses:SendRawEmail"],
+                    "Resource": f"arn:aws:ses:us-east-1:123456789012:identity/{email_identity}",
+                }
+            ],
+        }
+    )
+
+    client.create_email_identity(EmailIdentity=email_identity)
+    client.create_email_identity_policy(
+        EmailIdentity=email_identity, PolicyName=policy_name, Policy=initial_policy
+    )
+
+    initial_policies = client.get_email_identity_policies(EmailIdentity=email_identity)
+    assert policy_name in initial_policies["Policies"]
+    assert initial_policies["Policies"][policy_name] == initial_policy
+
+    response = client.update_email_identity_policy(
+        EmailIdentity=email_identity, PolicyName=policy_name, Policy=updated_policy
+    )
+
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    updated_policies = client.get_email_identity_policies(EmailIdentity=email_identity)
+    assert policy_name in updated_policies["Policies"]
+    assert updated_policies["Policies"][policy_name] == updated_policy
+    assert updated_policies["Policies"][policy_name] != initial_policy
+
+    new_policy_name = "NewPolicy"
+    response = client.update_email_identity_policy(
+        EmailIdentity=email_identity, PolicyName=new_policy_name, Policy=initial_policy
+    )
+
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    final_policies = client.get_email_identity_policies(EmailIdentity=email_identity)
+    assert new_policy_name in final_policies["Policies"]
+    assert final_policies["Policies"][new_policy_name] == initial_policy
+
+
+@mock_aws
+def test_get_email_identity_policies():
+    client = boto3.client("sesv2", region_name="us-east-1")
+    email_identity = "example.com"
+    policy_name = "MyPolicy"
+    policy = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": {"AWS": "arn:aws:iam::123456789012:root"},
+                    "Action": ["ses:SendEmail", "ses:SendRawEmail"],
+                    "Resource": f"arn:aws:ses:ap-southeast-1:123456789012:identity/{email_identity}",
+                }
+            ],
+        }
+    )
+
+    client.create_email_identity(EmailIdentity=email_identity)
+    client.create_email_identity_policy(
+        EmailIdentity=email_identity, PolicyName=policy_name, Policy=policy
+    )
+
+    response = client.get_email_identity_policies(EmailIdentity=email_identity)
+
+    assert policy_name in response["Policies"]
+    assert response["Policies"][policy_name] == policy
