@@ -7,7 +7,7 @@ from moto import mock_aws
 from tests import allow_aws_request
 
 
-def sqs_aws_verified():
+def sqs_aws_verified(fifo_queue: bool = False):
     """
     Function that is verified to work against AWS.
     Can be run against AWS at any time by setting:
@@ -25,12 +25,20 @@ def sqs_aws_verified():
         @wraps(func)
         def pagination_wrapper(**kwargs):
             queue_name = "q" + str(uuid4())[0:6]
+            if fifo_queue:
+                queue_name += ".fifo"
             kwargs["queue_name"] = queue_name
 
             def create_queue_and_test():
                 client = boto3.client("sqs", region_name="us-east-1")
 
-                queue_url = client.create_queue(QueueName=queue_name)["QueueUrl"]
+                create_kwargs = {}
+                if fifo_queue:
+                    create_kwargs["Attributes"] = {"FifoQueue": "true"}
+
+                queue_url = client.create_queue(QueueName=queue_name, **create_kwargs)[
+                    "QueueUrl"
+                ]
                 kwargs["queue_url"] = queue_url
                 try:
                     resp = func(**kwargs)
