@@ -64,7 +64,7 @@ def test_create_web_acl():
     )
     web_acl = res.json["Summary"]
     assert web_acl.get("ARN").startswith(
-        f"arn:aws:wafv2:global:{ACCOUNT_ID}:global/webacl/Carl/"
+        f"arn:aws:wafv2:us-east-1:{ACCOUNT_ID}:global/webacl/Carl/"
     )
 
 
