@@ -34,7 +34,7 @@ def test_create_web_acl(region, partition):
     res = conn.create_web_acl(**CREATE_WEB_ACL_BODY("Carl", "CLOUDFRONT"))
     web_acl = res["Summary"]
     assert web_acl.get("ARN").startswith(
-        f"arn:aws:wafv2:global:{ACCOUNT_ID}:global/webacl/Carl/"
+        f"arn:aws:wafv2:us-east-1:{ACCOUNT_ID}:global/webacl/Carl/"
     )
 
 
@@ -323,10 +323,12 @@ def test_ip_set_crud():
             Addresses=["10.0.0.0/8"],
             LockToken="aaaaaaaaaaaaaaaaaa",  # invalid lock token
         )
-    e.value.response["Error"]["Code"] == "WAFOptimisticLockException"
-    e.value.response["Error"][
-        "Message"
-    ] == "AWS WAF couldn’t save your changes because someone changed the resource after you started to edit it. Reapply your changes."
+    err = e.value.response["Error"]
+    assert err["Code"] == "WAFOptimisticLockException"
+    assert (
+        err["Message"]
+        == "AWS WAF couldn’t save your changes because someone changed the resource after you started to edit it. Reapply your changes."
+    )
 
     update_response = client.update_ip_set(
         Name="test-ip-set",
@@ -354,10 +356,8 @@ def test_ip_set_crud():
     assert len(list_response["IPSets"]) == 1
 
     assert all(
-        [
-            key in list_response["IPSets"][0]
-            for key in ["ARN", "Description", "Id", "LockToken", "Name"]
-        ]
+        key in list_response["IPSets"][0]
+        for key in ["ARN", "Description", "Id", "LockToken", "Name"]
     )
 
     client.delete_ip_set(
@@ -369,10 +369,12 @@ def test_ip_set_crud():
 
     with pytest.raises(ClientError) as e:
         client.get_ip_set(Name=summary["Name"], Scope="CLOUDFRONT", Id=summary["Id"])
-    e.value.response["Error"]["Code"] == "WAFNonexistentItemException"
-    e.value.response["Error"][
-        "Message"
-    ] == "AWS WAF couldn’t perform the operation because your resource doesn’t exist."
+    err = e.value.response["Error"]
+    assert err["Code"] == "WAFNonexistentItemException"
+    assert (
+        err["Message"]
+        == "AWS WAF couldn’t perform the operation because your resource doesn’t exist."
+    )
 
 
 @mock_aws
